@@ -1,25 +1,24 @@
-
 /* Jim - A small embeddable Tcl interpreter
  *
  * Copyright 2005 Salvatore Sanfilippo <antirez@invece.org>
  * Copyright 2005 Clemens Hintze <c.hintze@gmx.net>
- * Copyright 2005 patthoyts - Pat Thoyts <patthoyts@users.sf.net> 
+ * Copyright 2005 patthoyts - Pat Thoyts <patthoyts@users.sf.net>
  * Copyright 2008 oharboe - Øyvind Harboe - oyvind.harboe@zylin.com
  * Copyright 2008 Andrew Lunn <andrew@lunn.ch>
  * Copyright 2008 Duane Ellis <openocd@duaneellis.com>
  * Copyright 2008 Uwe Klein <uklein@klein-messgeraete.de>
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 
+ *
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above
  *    copyright notice, this list of conditions and the following
  *    disclaimer in the documentation and/or other materials
  *    provided with the distribution.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE JIM TCL PROJECT ``AS IS'' AND ANY
  * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
  * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
@@ -32,35 +31,44 @@
  * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- * 
+ *
  * The views and conclusions contained in the software and documentation
  * are those of the authors and should not be interpreted as representing
  * official policies, either expressed or implied, of the Jim Tcl Project.
  **/
 
-#include "jim.h"
 #include "jimautoconf.h"
-#include "jim-eventloop.h"
+#include <jim.h>
+#include <jim-eventloop.h>
 
-/* POSIX includes */
-#include <sys/time.h>
-#include <sys/types.h>
+#include <time.h>
 #include <string.h>
-#include <unistd.h>
 #include <errno.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
 
 #if defined(__MINGW32__)
 #include <windows.h>
 #include <winsock.h>
-#define msleep Sleep
+#ifndef HAVE_USLEEP
+#define usleep(US) Sleep((US) / 1000)
+#define HAVE_USLEEP
+#endif
 #else
+#include <sys/types.h>
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
+#endif
+#endif
 
 #ifndef HAVE_USLEEP
 /* XXX: Implement this in terms of select() or nanosleep() */
-#define usleep(US)
-#endif
-#define msleep(MS) sleep((MS) / 1000); usleep(((MS) % 1000) * 1000);
+#define usleep(US) sleep((US) / 1000000)
+#warning "sub-second sleep not supported"
 #endif
 
 /* --- */
@@ -68,7 +76,7 @@
 /* File event structure */
 typedef struct Jim_FileEvent
 {
-    FILE *handle;
+    int fd;
     int mask;                   /* one of JIM_EVENT_(READABLE|WRITABLE|EXCEPTION) */
     Jim_FileProc *fileProc;
     Jim_EventFinalizerProc *finalizerProc;
@@ -80,10 +88,8 @@ typedef struct Jim_FileEvent
 typedef struct Jim_TimeEvent
 {
     jim_wide id;                /* time event identifier. */
-    int mode;                   /* restart, repetitive .. UK */
-    long initialms;             /* initial relativ timer value UK */
-    long when_sec;              /* seconds */
-    long when_ms;               /* milliseconds */
+    jim_wide initialus;         /* initial relative timer value in microseconds */
+    jim_wide when;              /* microseconds */
     Jim_TimeProc *timeProc;
     Jim_EventFinalizerProc *finalizerProc;
     void *clientData;
@@ -93,9 +99,10 @@ typedef struct Jim_TimeEvent
 /* Per-interp stucture containing the state of the event loop */
 typedef struct Jim_EventLoop
 {
-    jim_wide timeEventNextId;
     Jim_FileEvent *fileEventHead;
     Jim_TimeEvent *timeEventHead;
+    jim_wide timeEventNextId;   /* highest event id created, starting at 1 */
+    time_t timeBase;
     int suppress_bgerror; /* bgerror returned break, so don't call it again */
 } Jim_EventLoop;
 
@@ -113,7 +120,7 @@ int Jim_EvalObjBackground(Jim_Interp *interp, Jim_Obj *scriptObjPtr)
     retval = Jim_EvalObj(interp, scriptObjPtr);
     interp->framePtr = savedFramePtr;
     /* Try to report the error (if any) via the bgerror proc */
-    if (retval != JIM_OK && !eventLoop->suppress_bgerror) {
+    if (retval != JIM_OK && retval != JIM_RETURN && !eventLoop->suppress_bgerror) {
         Jim_Obj *objv[2];
         int rc = JIM_ERR;
 
@@ -141,14 +148,24 @@ int Jim_EvalObjBackground(Jim_Interp *interp, Jim_Obj *scriptObjPtr)
 }
 
 
-void Jim_CreateFileHandler(Jim_Interp *interp, FILE * handle, int mask,
+/**
+ * Register a file event handler on the given file descriptor with the given mask
+ * (may be 1 or more of JIM_EVENT_xxx)
+ *
+ * When the event occurs, proc is called with clientData and the mask of events that occurred.
+ * When the filehandler is removed, finalizerProc is called.
+ *
+ * Note that no check is made that only one handler is registered for the given
+ * event(s).
+ */
+void Jim_CreateFileHandler(Jim_Interp *interp, int fd, int mask,
     Jim_FileProc * proc, void *clientData, Jim_EventFinalizerProc * finalizerProc)
 {
     Jim_FileEvent *fe;
     Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
 
     fe = Jim_Alloc(sizeof(*fe));
-    fe->handle = handle;
+    fe->fd = fd;
     fe->mask = mask;
     fe->fileProc = proc;
     fe->finalizerProc = finalizerProc;
@@ -157,87 +174,133 @@ void Jim_CreateFileHandler(Jim_Interp *interp, FILE * handle, int mask,
     eventLoop->fileEventHead = fe;
 }
 
-void Jim_DeleteFileHandler(Jim_Interp *interp, FILE * handle)
+static int JimEventHandlerScript(Jim_Interp *interp, void *clientData, int mask)
 {
-    Jim_FileEvent *fe, *prev = NULL;
+    return Jim_EvalObjBackground(interp, (Jim_Obj *)clientData);
+}
+
+static void JimEventHandlerScriptFinalize(Jim_Interp *interp, void *clientData)
+{
+    Jim_DecrRefCount(interp, (Jim_Obj *)clientData);
+}
+
+/**
+ * A convenience version of Jim_CreateFileHandler() which evaluates
+ * scriptObj with Jim_EvalObjBackground() when the event occurs.
+ */
+void Jim_CreateScriptFileHandler(Jim_Interp *interp, int fd, int mask,
+    Jim_Obj *scriptObj)
+{
+    Jim_IncrRefCount(scriptObj);
+    Jim_CreateFileHandler(interp, fd, mask, JimEventHandlerScript, scriptObj, JimEventHandlerScriptFinalize);
+}
+
+/**
+ * If there is a file handler registered with the given mask, return the clientData
+ * for the (first) handler.
+ * Otherwise return NULL.
+ */
+void *Jim_FindFileHandler(Jim_Interp *interp, int fd, int mask)
+{
+    Jim_FileEvent *fe;
     Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
 
-    fe = eventLoop->fileEventHead;
-    while (fe) {
-        if (fe->handle == handle) {
+    for (fe = eventLoop->fileEventHead; fe; fe = fe->next) {
+        if (fe->fd == fd && (fe->mask & mask)) {
+            return fe->clientData;
+        }
+    }
+    return NULL;
+}
+
+/**
+ * Removes all event handlers for 'handle' that match 'mask'.
+ */
+void Jim_DeleteFileHandler(Jim_Interp *interp, int fd, int mask)
+{
+    Jim_FileEvent *fe, *next, *prev = NULL;
+    Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
+
+    for (fe = eventLoop->fileEventHead; fe; fe = next) {
+        next = fe->next;
+        if (fe->fd == fd && (fe->mask & mask)) {
+            /* Remove this entry from the list */
             if (prev == NULL)
-                eventLoop->fileEventHead = fe->next;
+                eventLoop->fileEventHead = next;
             else
-                prev->next = fe->next;
+                prev->next = next;
             if (fe->finalizerProc)
                 fe->finalizerProc(interp, fe->clientData);
             Jim_Free(fe);
-            return;
+            continue;
         }
         prev = fe;
-        fe = fe->next;
     }
 }
 
-static void JimGetTime(long *seconds, long *milliseconds)
+/**
+ * Returns the time since interp creation in microseconds.
+ */
+static jim_wide JimGetTimeUsec(Jim_EventLoop *eventLoop)
 {
+    long long now;
     struct timeval tv;
 
-    gettimeofday(&tv, NULL);
-    *seconds = tv.tv_sec;
-    *milliseconds = tv.tv_usec / 1000;
+#if defined(HAVE_CLOCK_GETTIME) && defined(CLOCK_MONOTONIC_RAW)
+    struct timespec ts;
+
+    if (clock_gettime(CLOCK_MONOTONIC_RAW, &ts) == 0) {
+        now = ts.tv_sec * 1000000LL + ts.tv_nsec / 1000;
+    }
+    else
+#endif
+    {
+        gettimeofday(&tv, NULL);
+
+        now = tv.tv_sec * 1000000LL + tv.tv_usec;
+    }
+
+    return now - eventLoop->timeBase;
 }
 
-jim_wide Jim_CreateTimeHandler(Jim_Interp *interp, jim_wide milliseconds,
+jim_wide Jim_CreateTimeHandler(Jim_Interp *interp, jim_wide us,
     Jim_TimeProc * proc, void *clientData, Jim_EventFinalizerProc * finalizerProc)
 {
     Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
-    jim_wide id = eventLoop->timeEventNextId++;
+    jim_wide id = ++eventLoop->timeEventNextId;
     Jim_TimeEvent *te, *e, *prev;
-    long cur_sec, cur_ms;
-
-    JimGetTime(&cur_sec, &cur_ms);
 
     te = Jim_Alloc(sizeof(*te));
     te->id = id;
-    te->mode = 0;
-    te->initialms = milliseconds;
-    te->when_sec = cur_sec + milliseconds / 1000;
-    te->when_ms = cur_ms + milliseconds % 1000;
-    if (te->when_ms >= 1000) {
-        te->when_sec++;
-        te->when_ms -= 1000;
-    }
+    te->initialus = us;
+    te->when = JimGetTimeUsec(eventLoop) + us;
     te->timeProc = proc;
     te->finalizerProc = finalizerProc;
     te->clientData = clientData;
 
     /* Add to the appropriate place in the list */
-    if (eventLoop->timeEventHead) {
-        prev = NULL;
-        for (e = eventLoop->timeEventHead; e; e = e->next) {
-            if (te->when_sec < e->when_sec || (te->when_sec == e->when_sec && te->when_ms < e->when_ms)) {
-                break;
-            }
-            prev = e;
-        }
-        if (prev) {
-            te->next = prev->next;
-            prev->next = te;
-            return id;
+    prev = NULL;
+    for (e = eventLoop->timeEventHead; e; e = e->next) {
+        if (te->when < e->when) {
+            break;
         }
+        prev = e;
+    }
+    if (prev) {
+        te->next = prev->next;
+        prev->next = te;
+    }
+    else {
+        te->next = eventLoop->timeEventHead;
+        eventLoop->timeEventHead = te;
     }
-
-    te->next = eventLoop->timeEventHead;
-    eventLoop->timeEventHead = te;
 
     return id;
 }
 
 static jim_wide JimParseAfterId(Jim_Obj *idObj)
 {
-    int len;
-    const char *tok = Jim_GetString(idObj, &len);
+    const char *tok = Jim_String(idObj);
     jim_wide id;
 
     if (strncmp(tok, "after#", 6) == 0 && Jim_StringToWide(tok + 6, &id, 10) == JIM_OK) {
@@ -303,19 +366,15 @@ jim_wide Jim_DeleteTimeHandler(Jim_Interp *interp, jim_wide id)
     Jim_TimeEvent *te;
     Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
 
-    if (id >= eventLoop->timeEventNextId) {
+    if (id > eventLoop->timeEventNextId) {
         return -2;              /* wrong event ID */
     }
 
     te = Jim_RemoveTimeHandler(eventLoop, id);
     if (te) {
         jim_wide remain;
-        long cur_sec, cur_ms;
 
-        JimGetTime(&cur_sec, &cur_ms);
-        
-        remain = (te->when_sec - cur_sec) * 1000;
-        remain += (te->when_ms - cur_ms);
+        remain = te->when - JimGetTimeUsec(eventLoop);
         remain = (remain < 0) ? 0 : remain;
 
         Jim_FreeTimeHandler(interp, te);
@@ -328,22 +387,21 @@ jim_wide Jim_DeleteTimeHandler(Jim_Interp *interp, jim_wide id)
 
 /* Process every pending time event, then every pending file event
  * (that may be registered by time event callbacks just processed).
- * Without special flags the function sleeps until some file event
- * fires, or when the next time event occurrs (if any).
+ * The behaviour depends upon the setting of flags:
  *
  * If flags is 0, the function does nothing and returns.
- * if flags has JIM_ALL_EVENTS set, all the kind of events are processed.
+ * if flags has JIM_ALL_EVENTS set, all event types are processed.
  * if flags has JIM_FILE_EVENTS set, file events are processed.
  * if flags has JIM_TIME_EVENTS set, time events are processed.
- * if flags has JIM_DONT_WAIT set the function returns ASAP until all
- * the events that's possible to process without to wait are processed.
+ * if flags has JIM_DONT_WAIT set, the function returns as soon as all
+ * the events that are possible to process without waiting are processed.
  *
- * The function returns the number of events processed or -1 if
+ * Returns the number of events processed or -1 if
  * there are no matching handlers, or -2 on error.
  */
 int Jim_ProcessEvents(Jim_Interp *interp, int flags)
 {
-    jim_wide sleep_ms = -1;
+    jim_wide sleep_us = -1;
     int processed = 0;
     Jim_EventLoop *eventLoop = Jim_GetAssocData(interp, "eventloop");
     Jim_FileEvent *fe = eventLoop->fileEventHead;
@@ -365,25 +423,23 @@ int Jim_ProcessEvents(Jim_Interp *interp, int flags)
 
     if (flags & JIM_DONT_WAIT) {
         /* Wait no time */
-        sleep_ms = 0;
+        sleep_us = 0;
     }
     else if (flags & JIM_TIME_EVENTS) {
         /* The nearest timer is always at the head of the list */
         if (eventLoop->timeEventHead) {
             Jim_TimeEvent *shortest = eventLoop->timeEventHead;
-            long now_sec, now_ms;
 
             /* Calculate the time missing for the nearest
              * timer to fire. */
-            JimGetTime(&now_sec, &now_ms);
-            sleep_ms = 1000 * (shortest->when_sec - now_sec) + (shortest->when_ms - now_ms);
-            if (sleep_ms < 0) {
-                sleep_ms = 1;
+            sleep_us = shortest->when - JimGetTimeUsec(eventLoop);
+            if (sleep_us < 0) {
+                sleep_us = 0;
             }
         }
         else {
             /* Wait forever */
-            sleep_ms = -1;
+            sleep_us = -1;
         }
     }
 
@@ -400,23 +456,21 @@ int Jim_ProcessEvents(Jim_Interp *interp, int flags)
 
         /* Check file events */
         while (fe != NULL) {
-            int fd = fileno(fe->handle);
-
             if (fe->mask & JIM_EVENT_READABLE)
-                FD_SET(fd, &rfds);
+                FD_SET(fe->fd, &rfds);
             if (fe->mask & JIM_EVENT_WRITABLE)
-                FD_SET(fd, &wfds);
+                FD_SET(fe->fd, &wfds);
             if (fe->mask & JIM_EVENT_EXCEPTION)
-                FD_SET(fd, &efds);
-            if (maxfd < fd)
-                maxfd = fd;
+                FD_SET(fe->fd, &efds);
+            if (maxfd < fe->fd)
+                maxfd = fe->fd;
             fe = fe->next;
         }
 
-        if (sleep_ms >= 0) {
+        if (sleep_us >= 0) {
             tvp = &tv;
-            tvp->tv_sec = sleep_ms / 1000;
-            tvp->tv_usec = 1000 * (sleep_ms % 1000);
+            tvp->tv_sec = sleep_us / 1000000;
+            tvp->tv_usec = sleep_us % 1000000;
         }
 
         retval = select(maxfd + 1, &rfds, &wfds, &efds, tvp);
@@ -427,40 +481,36 @@ int Jim_ProcessEvents(Jim_Interp *interp, int flags)
                 Jim_SetResultString(interp, "non-waitable filehandle", -1);
                 return -2;
             }
-            /* XXX: What about EINTR? */
         }
         else if (retval > 0) {
             fe = eventLoop->fileEventHead;
             while (fe != NULL) {
-                int fd = fileno(fe->handle);
+                int mask = 0;
+                int fd = fe->fd;
 
-                if ((fe->mask & JIM_EVENT_READABLE && FD_ISSET(fd, &rfds)) ||
-                    (fe->mask & JIM_EVENT_WRITABLE && FD_ISSET(fd, &wfds)) ||
-                    (fe->mask & JIM_EVENT_EXCEPTION && FD_ISSET(fd, &efds))) {
-                    int mask = 0;
+                if ((fe->mask & JIM_EVENT_READABLE) && FD_ISSET(fd, &rfds))
+                    mask |= JIM_EVENT_READABLE;
+                if (fe->mask & JIM_EVENT_WRITABLE && FD_ISSET(fd, &wfds))
+                    mask |= JIM_EVENT_WRITABLE;
+                if (fe->mask & JIM_EVENT_EXCEPTION && FD_ISSET(fd, &efds))
+                    mask |= JIM_EVENT_EXCEPTION;
 
-                    if ((fe->mask & JIM_EVENT_READABLE) && FD_ISSET(fd, &rfds)) {
-                        mask |= JIM_EVENT_READABLE;
-                        if ((fe->mask & JIM_EVENT_FEOF) && feof(fe->handle))
-                            mask |= JIM_EVENT_FEOF;
-                    }
-                    if (fe->mask & JIM_EVENT_WRITABLE && FD_ISSET(fd, &wfds))
-                        mask |= JIM_EVENT_WRITABLE;
-                    if (fe->mask & JIM_EVENT_EXCEPTION && FD_ISSET(fd, &efds))
-                        mask |= JIM_EVENT_EXCEPTION;
-                    if (fe->fileProc(interp, fe->clientData, mask) != JIM_OK) {
+                if (mask) {
+                    int ret = fe->fileProc(interp, fe->clientData, mask);
+                    if (ret != JIM_OK && ret != JIM_RETURN) {
                         /* Remove the element on handler error */
-                        Jim_DeleteFileHandler(interp, fe->handle);
+                        Jim_DeleteFileHandler(interp, fd, mask);
+                        /* At this point fe is no longer valid - it will be assigned below */
                     }
                     processed++;
                     /* After an event is processed our file event list
                      * may no longer be the same, so what we do
                      * is to clear the bit for this file descriptor and
                      * restart again from the head. */
-                    fe = eventLoop->fileEventHead;
                     FD_CLR(fd, &rfds);
                     FD_CLR(fd, &wfds);
                     FD_CLR(fd, &efds);
+                    fe = eventLoop->fileEventHead;
                 }
                 else {
                     fe = fe->next;
@@ -469,24 +519,22 @@ int Jim_ProcessEvents(Jim_Interp *interp, int flags)
         }
     }
 #else
-    if (sleep_ms > 0) {
-        msleep(sleep_ms);
+    if (sleep_us > 0) {
+        usleep(sleep_us);
     }
 #endif
 
     /* Check time events */
     te = eventLoop->timeEventHead;
-    maxId = eventLoop->timeEventNextId - 1;
+    maxId = eventLoop->timeEventNextId;
     while (te) {
-        long now_sec, now_ms;
         jim_wide id;
 
         if (te->id > maxId) {
             te = te->next;
             continue;
         }
-        JimGetTime(&now_sec, &now_ms);
-        if (now_sec > te->when_sec || (now_sec == te->when_sec && now_ms >= te->when_ms)) {
+        if (JimGetTimeUsec(eventLoop) >= te->when) {
             id = te->id;
             /* Remove from the list before executing */
             Jim_RemoveTimeHandler(eventLoop, id);
@@ -556,9 +604,7 @@ static int JimELVwaitCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
     }
     else {
         /* If a result was left, it is an error */
-        int len;
-        Jim_GetString(interp->result, &len);
-        if (len) {
+        if (Jim_Length(Jim_GetResult(interp))) {
             return JIM_ERR;
         }
     }
@@ -569,16 +615,19 @@ static int JimELVwaitCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
         Jim_Obj *currValue;
         currValue = Jim_GetGlobalVariable(interp, argv[1], JIM_NONE);
         /* Stop the loop if the vwait-ed variable changed value,
-         * or if was unset and now is set (or the contrary). */
+         * or if was unset and now is set (or the contrary)
+         * or if a signal was caught
+         */
         if ((oldValue && !currValue) ||
             (!oldValue && currValue) ||
-            (oldValue && currValue && !Jim_StringEqObj(oldValue, currValue)))
+            (oldValue && currValue && !Jim_StringEqObj(oldValue, currValue)) ||
+            Jim_CheckSignal(interp)) {
             break;
+        }
     }
     if (oldValue)
         Jim_DecrRefCount(interp, oldValue);
 
-
     if (rc == -2) {
         return JIM_ERR;
     }
@@ -630,7 +679,8 @@ static void JimAfterTimeEventFinalizer(Jim_Interp *interp, void *clientData)
 static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
 {
     Jim_EventLoop *eventLoop = Jim_CmdPrivData(interp);
-    jim_wide ms = 0, id;
+    double ms = 0;
+    jim_wide id;
     Jim_Obj *objPtr, *idObjPtr;
     static const char * const options[] = {
         "cancel", "info", "idle", NULL
@@ -643,7 +693,7 @@ static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
         Jim_WrongNumArgs(interp, 1, argv, "option ?arg ...?");
         return JIM_ERR;
     }
-    if (Jim_GetWide(interp, argv[1], &ms) != JIM_OK) {
+    if (Jim_GetDouble(interp, argv[1], &ms) != JIM_OK) {
         if (Jim_GetEnum(interp, argv[1], options, &option, "argument", JIM_ERRMSG) != JIM_OK) {
             return JIM_ERR;
         }
@@ -651,7 +701,7 @@ static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
     }
     else if (argc == 2) {
         /* Simply a sleep */
-        msleep(ms);
+        usleep(ms * 1000);
         return JIM_OK;
     }
 
@@ -665,7 +715,7 @@ static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
         case AFTER_CREATE: {
             Jim_Obj *scriptObj = Jim_ConcatObj(interp, argc - 2, argv + 2);
             Jim_IncrRefCount(scriptObj);
-            id = Jim_CreateTimeHandler(interp, ms, JimAfterTimeHandler, scriptObj,
+            id = Jim_CreateTimeHandler(interp, (jim_wide)(ms * 1000), JimAfterTimeHandler, scriptObj,
                 JimAfterTimeEventFinalizer);
             objPtr = Jim_NewStringObj(interp, NULL, 0);
             Jim_AppendString(interp, objPtr, "after#", -1);
@@ -685,12 +735,12 @@ static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
                 jim_wide remain = 0;
 
                 id = JimParseAfterId(argv[2]);
-                if (id < 0) {
+                if (id <= 0) {
                     /* Not an event id, so search by script */
                     Jim_Obj *scriptObj = Jim_ConcatObj(interp, argc - 2, argv + 2);
                     id = JimFindAfterByScript(eventLoop, scriptObj);
                     Jim_FreeNewObj(interp, scriptObj);
-                    if (id < 0) {
+                    if (id <= 0) {
                         /* Not found */
                         break;
                     }
@@ -723,7 +773,7 @@ static int JimELAfterCommand(Jim_Interp *interp, int argc, Jim_Obj *const *argv)
                     if (e && e->timeProc == JimAfterTimeHandler) {
                         Jim_Obj *listObj = Jim_NewListObj(interp, NULL, 0);
                         Jim_ListAppendElement(interp, listObj, e->clientData);
-                        Jim_ListAppendElement(interp, listObj, Jim_NewStringObj(interp, e->initialms ? "timer" : "idle", -1));
+                        Jim_ListAppendElement(interp, listObj, Jim_NewStringObj(interp, e->initialus ? "timer" : "idle", -1));
                         Jim_SetResult(interp, listObj);
                         return JIM_OK;
                     }
@@ -744,14 +794,11 @@ int Jim_eventloopInit(Jim_Interp *interp)
 {
     Jim_EventLoop *eventLoop;
 
-    if (Jim_PackageProvide(interp, "eventloop", "1.0", JIM_ERRMSG))
-        return JIM_ERR;
+    Jim_PackageProvideCheck(interp, "eventloop");
 
     eventLoop = Jim_Alloc(sizeof(*eventLoop));
-    eventLoop->fileEventHead = NULL;
-    eventLoop->timeEventHead = NULL;
-    eventLoop->timeEventNextId = 1;
-    eventLoop->suppress_bgerror = 0;
+    memset(eventLoop, 0, sizeof(*eventLoop));
+
     Jim_SetAssocData(interp, "eventloop", JimELAssocDataDeleProc, eventLoop);
 
     Jim_CreateCommand(interp, "vwait", JimELVwaitCommand, eventLoop, NULL);
