@@ -252,6 +252,115 @@ $f writable {incr y}
 $f close
 puts "TEST 34 PASSED"
 
+# REGTEST 35
+# caching of command resolution after local proc deleted
+set result {}
+proc x {} { }
+proc p {n} {
+    if {$n in {2 3}} {
+        local proc x {} { }
+    }
+    x
+}
+foreach i {1 2 3 4} {
+    p $i
+}
+puts "TEST 35 PASSED"
+
+# REGTEST 36
+# divide integer by integer zero
+catch {/ 1 0}
+puts "TEST 36 PASSED"
+
+# REGTEST 37
+# ternary operator order
+catch {expr {1 : 2 ? 3}}
+puts "TEST 37 PASSED"
+
+# REGTEST 38
+# refcount with interpolation and expr
+set b(-1) 5
+set a $b($(-1))
+puts "TEST 38 PASSED"
+
+# REGTEST 39
+# invalid ternary expr
+catch {set a $(5?6,7?8:?9:10%11:12)}
+puts "TEST 39 PASSED"
+
+# REGTEST 40
+# ref count problem - double free
+set d [dict create a b]
+lsort r($d)
+catch {dict remove r($d) m}
+puts "TEST 40 PASSED"
+
+# REGTEST 41
+# access invalid memory on no scan conversion char
+catch {scan x %3}
+puts "TEST 41 PASSED"
+
+# REGTEST 42
+# | and |& are not acceptable as prefixes
+catch {exec dummy |x second}
+puts "TEST 42 PASSED"
+
+# REGTEST 43
+# too many flags to format
+catch {format %----------------------------------------d 1}
+puts "TEST 43 PASSED"
+
+# REGTEST 44
+# lsort -unique with no duplicate - invalid memory write
+lsort -unique {a b c d}
+puts "TEST 44 PASSED"
+
+# REGTEST 45
+# regexp with missing close brace for count
+catch [list regexp "u{0" x]
+puts "TEST 45 PASSED"
+
+# REGTEST 46
+# scan with no stringrep
+catch {scan $(1) $(1)}
+puts "TEST 46 PASSED"
+
+# REGTEST 47
+# Invalid ternary expression
+catch {set a $(99?9,99?9:*9:999)?9)}
+puts "TEST 47 PASSED"
+
+# REGTEST 48
+# scan: -ve XPG3 specifier
+catch {scan a {%-9999999$c}}
+puts "TEST 48 PASSED"
+
+# REGTEST 49
+# format: precision too large
+catch {format %1.9999999999f 1.0}
+puts "TEST 49 PASSED"
+
+# REGTEST 50
+# expr missing operand
+catch {expr {>>-$x}}
+puts "TEST 50 PASSED"
+
+# REGTEST 51
+# expr convert invalid value to boolean
+catch {expr {2 && "abc$"}}
+puts "TEST 51 PASSED"
+
+# REGTEST 52
+# lsearch -command with too few args
+catch {lsearch -all -command abc def}
+puts "TEST 52 PASSED"
+
+# REGTEST 53
+# string last with invalid index
+catch {string last foo bar -1}
+puts "TEST 53 PASSED"
+
+
 # TAKE THE FOLLOWING puts AS LAST LINE
 
 puts "--- ALL TESTS PASSED ---"
