@@ -1,5 +1,5 @@
 # Loads some Tcl-compatible features.
-# I/O commands, case, lassign, parray, errorInfo, ::tcl_platform, ::env
+# I/O commands, parray, open |..., errorInfo, ::env
 # try, throw, file copy, file delete -force
 #
 # (c) 2008 Steve Bennett <steveb@workware.net.au>
@@ -63,9 +63,8 @@ proc fileevent {args} {
 	tailcall {*}$args
 }
 
-# Second, option argument is a glob pattern
+# Second, optional argument is a glob pattern
 # Third, optional argument is a "putter" function
-#
 proc parray {arrayname {pattern *} {puts puts}} {
 	upvar $arrayname a
 
@@ -119,9 +118,9 @@ proc {file copy} {{force {}} source target} {
 }
 
 # 'open "|..." ?mode?" will invoke this wrapper around exec/pipe
-# Note that we return a lambda which also provides the 'pid' command
+# Note that we return a lambda that also provides the 'pid' command
 proc popen {cmd {mode r}} {
-	lassign [socket pipe] r w
+	lassign [pipe] r w
 	try {
 		if {[string match "w*" $mode]} {
 			lappend cmd <@$r &
@@ -138,11 +137,26 @@ proc popen {cmd {mode r}} {
 			if {$cmd eq "pid"} {
 				return $pids
 			}
+			if {$cmd eq "getfd"} {
+				$f getfd
+			}
 			if {$cmd eq "close"} {
 				$f close
 				# And wait for the child processes to complete
-				foreach p $pids { os.wait $p }
-				return
+				set retopts {}
+				foreach p $pids {
+					lassign [wait $p] status - rc
+					if {$status eq "CHILDSTATUS"} {
+						if {$rc == 0} {
+							continue
+						}
+						set msg "child process exited abnormally"
+					} else {
+						set msg "child killed: received signal"
+					}
+					set retopts [list -code error -errorcode [list $status $p $rc] $msg]
+				}
+				return {*}$retopts
 			}
 			tailcall $f $cmd {*}$args
 		}
@@ -153,7 +167,7 @@ proc popen {cmd {mode r}} {
 	}
 }
 
-# A wrapper around 'pid' which can return the pids for 'popen'
+# A wrapper around 'pid' that can return the pids for 'popen'
 local proc pid {{channelId {}}} {
 	if {$channelId eq ""} {
 		tailcall upcall pid
@@ -167,76 +181,6 @@ local proc pid {{channelId {}}} {
 	return $pids
 }
 
-# try/on/finally conceptually similar to Tcl 8.6
-#
-# Usage: try ?catchopts? script ?onclause ...? ?finallyclause?
-#
-# Where:
-#   onclause is:       on codes {?resultvar? ?optsvar?} script
-#
-#   codes is: a list of return codes (ok, error, etc. or integers), or * for any
-#
-#   finallyclause is:  finally script
-#
-#
-# Where onclause is: on codes {?resultvar? ?optsvar?}
-proc try {args} {
-	set catchopts {}
-	while {[string match -* [lindex $args 0]]} {
-		set args [lassign $args opt]
-		if {$opt eq "--"} {
-			break
-		}
-		lappend catchopts $opt
-	}
-	if {[llength $args] == 0} {
-		return -code error {wrong # args: should be "try ?options? script ?argument ...?"}
-	}
-	set args [lassign $args script]
-	set code [catch -eval {*}$catchopts {uplevel 1 $script} msg opts]
-
-	set handled 0
-
-	foreach {on codes vars script} $args {
-		switch -- $on \
-			on {
-				if {!$handled && ($codes eq "*" || [info returncode $code] in $codes)} {
-					lassign $vars msgvar optsvar
-					if {$msgvar ne ""} {
-						upvar $msgvar hmsg
-						set hmsg $msg
-					}
-					if {$optsvar ne ""} {
-						upvar $optsvar hopts
-						set hopts $opts
-					}
-					# Override any body result
-					set code [catch {uplevel 1 $script} msg opts]
-					incr handled
-				}
-			} \
-			finally {
-				set finalcode [catch {uplevel 1 $codes} finalmsg finalopts]
-				if {$finalcode} {
-					# Override any body or handler result
-					set code $finalcode
-					set msg $finalmsg
-					set opts $finalopts
-				}
-				break
-			} \
-			default {
-				return -code error "try: expected 'on' or 'finally', got '$on'"
-			}
-	}
-
-	if {$code} {
-		incr opts(-level)
-		return {*}$opts $msg
-	}
-	return $msg
-}
-
 # Generates an exception with the given code (ok, error, etc. or an integer)
 # and the given message
 proc throw {code {msg ""}} {
