@@ -1,19 +1,8 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
+
 /***************************************************************************
  *   Copyright (C) 2005 by Dominic Rath                                    *
  *   Dominic.Rath@gmx.de                                                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef OPENOCD_FLASH_NOR_CFI_H
@@ -108,17 +97,17 @@ struct cfi_spansion_pri_ext {
 	uint8_t  pri[3];
 	uint8_t  major_version;
 	uint8_t  minor_version;
-	uint8_t  SiliconRevision; /* bits 1-0: Address Sensitive Unlock */
-	uint8_t  EraseSuspend;
-	uint8_t  BlkProt;
-	uint8_t  TmpBlkUnprotect;
-	uint8_t  BlkProtUnprot;
-	uint8_t  SimultaneousOps;
-	uint8_t  BurstMode;
-	uint8_t  PageMode;
-	uint8_t  VppMin;
-	uint8_t  VppMax;
-	uint8_t  TopBottom;
+	uint8_t  silicon_revision; /* bits 1-0: Address Sensitive Unlock */
+	uint8_t  erase_suspend;
+	uint8_t  blk_prot;
+	uint8_t  tmp_blk_unprotected;
+	uint8_t  blk_prot_unprot;
+	uint8_t  simultaneous_ops;
+	uint8_t  burst_mode;
+	uint8_t  page_mode;
+	uint8_t  vpp_min;
+	uint8_t  vpp_max;
+	uint8_t  top_bottom;
 	int _reversed_geometry;
 	uint32_t _unlock1;
 	uint32_t _unlock2;
@@ -160,7 +149,7 @@ int cfi_protect(struct flash_bank *bank, int set, unsigned int first,
 int cfi_probe(struct flash_bank *bank);
 int cfi_auto_probe(struct flash_bank *bank);
 int cfi_protect_check(struct flash_bank *bank);
-int cfi_get_info(struct flash_bank *bank, char *buf, int buf_size);
+int cfi_get_info(struct flash_bank *bank, struct command_invocation *cmd);
 int cfi_flash_bank_cmd(struct flash_bank *bank, unsigned int argc, const char **argv);
 
 uint32_t cfi_flash_address(struct flash_bank *bank, int sector, uint32_t offset);
