@@ -1,18 +1,7 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2010 by Antonio Borneo <borneo.antonio@gmail.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 /* STM Serial Memory Interface (SMI) controller is a SPI bus controller
@@ -41,34 +30,33 @@
 #include <jtag/jtag.h>
 #include <helper/time_support.h>
 
-#define SMI_READ_REG(a) (_SMI_READ_REG(a))
-#define _SMI_READ_REG(a)			\
-{									\
-	int __a;						\
-	uint32_t __v;					\
+#define SMI_READ_REG(a)				\
+({									\
+	int _ret;						\
+	uint32_t _value;				\
 									\
-	__a = target_read_u32(target, io_base + (a), &__v); \
-	if (__a != ERROR_OK)			\
-		return __a;					\
-	__v;							\
-}
+	_ret = target_read_u32(target, io_base + (a), &_value); \
+	if (_ret != ERROR_OK)			\
+		return _ret;				\
+	_value;							\
+})
 
 #define SMI_WRITE_REG(a, v)			\
 {									\
-	int __r;						\
+	int _retval;					\
 									\
-	__r = target_write_u32(target, io_base + (a), (v)); \
-	if (__r != ERROR_OK)			\
-		return __r;					\
+	_retval = target_write_u32(target, io_base + (a), (v)); \
+	if (_retval != ERROR_OK)		\
+		return _retval;				\
 }
 
 #define SMI_POLL_TFF(timeout)		\
 {									\
-	int __r;						\
+	int _retval;					\
 									\
-	__r = poll_tff(target, io_base, timeout); \
-	if (__r != ERROR_OK)			\
-		return __r;					\
+	_retval = poll_tff(target, io_base, timeout); \
+	if (_retval != ERROR_OK)		\
+		return _retval;				\
 }
 
 #define SMI_SET_SW_MODE()	SMI_WRITE_REG(SMI_CR1, \
@@ -115,7 +103,7 @@
 #define SMI_MAX_TIMEOUT  (3000)
 
 struct stmsmi_flash_bank {
-	int probed;
+	bool probed;
 	uint32_t io_base;
 	uint32_t bank_num;
 	const struct flash_device *dev;
@@ -145,13 +133,13 @@ FLASH_BANK_COMMAND_HANDLER(stmsmi_flash_bank_command)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	stmsmi_info = malloc(sizeof(struct stmsmi_flash_bank));
-	if (stmsmi_info == NULL) {
+	if (!stmsmi_info) {
 		LOG_ERROR("not enough memory");
 		return ERROR_FAIL;
 	}
 
 	bank->driver_priv = stmsmi_info;
-	stmsmi_info->probed = 0;
+	stmsmi_info->probed = false;
 
 	return ERROR_OK;
 }
@@ -269,17 +257,14 @@ static int smi_write_enable(struct flash_bank *bank)
 static uint32_t erase_command(struct stmsmi_flash_bank *stmsmi_info,
 	uint32_t offset)
 {
-	union {
-		uint32_t command;
-		uint8_t x[4];
-	} cmd;
+	uint8_t cmd_bytes[] = {
+		stmsmi_info->dev->erase_cmd,
+		offset >> 16,
+		offset >> 8,
+		offset
+	};
 
-	cmd.x[0] = stmsmi_info->dev->erase_cmd;
-	cmd.x[1] = offset >> 16;
-	cmd.x[2] = offset >> 8;
-	cmd.x[3] = offset;
-
-	return cmd.command;
+	return le_to_h_u32(cmd_bytes);
 }
 
 static int smi_erase_sector(struct flash_bank *bank, int sector)
@@ -316,22 +301,22 @@ static int smi_erase_sector(struct flash_bank *bank, int sector)
 	return ERROR_OK;
 }
 
-static int stmsmi_erase(struct flash_bank *bank, int first, int last)
+static int stmsmi_erase(struct flash_bank *bank, unsigned int first,
+		unsigned int last)
 {
 	struct target *target = bank->target;
 	struct stmsmi_flash_bank *stmsmi_info = bank->driver_priv;
 	uint32_t io_base = stmsmi_info->io_base;
 	int retval = ERROR_OK;
-	int sector;
 
-	LOG_DEBUG("%s: from sector %d to sector %d", __func__, first, last);
+	LOG_DEBUG("%s: from sector %u to sector %u", __func__, first, last);
 
 	if (target->state != TARGET_HALTED) {
 		LOG_ERROR("Target not halted");
 		return ERROR_TARGET_NOT_HALTED;
 	}
 
-	if ((first < 0) || (last < first) || (last >= bank->num_sectors)) {
+	if ((last < first) || (last >= bank->num_sectors)) {
 		LOG_ERROR("Flash sector invalid");
 		return ERROR_FLASH_SECTOR_INVALID;
 	}
@@ -341,14 +326,17 @@ static int stmsmi_erase(struct flash_bank *bank, int first, int last)
 		return ERROR_FLASH_BANK_NOT_PROBED;
 	}
 
-	for (sector = first; sector <= last; sector++) {
+	for (unsigned int sector = first; sector <= last; sector++) {
 		if (bank->sectors[sector].is_protected) {
-			LOG_ERROR("Flash sector %d protected", sector);
+			LOG_ERROR("Flash sector %u protected", sector);
 			return ERROR_FAIL;
 		}
 	}
 
-	for (sector = first; sector <= last; sector++) {
+	if (stmsmi_info->dev->erase_cmd == 0x00)
+		return ERROR_FLASH_OPER_UNSUPPORTED;
+
+	for (unsigned int sector = first; sector <= last; sector++) {
 		retval = smi_erase_sector(bank, sector);
 		if (retval != ERROR_OK)
 			break;
@@ -361,11 +349,9 @@ static int stmsmi_erase(struct flash_bank *bank, int first, int last)
 }
 
 static int stmsmi_protect(struct flash_bank *bank, int set,
-	int first, int last)
+		unsigned int first, unsigned int last)
 {
-	int sector;
-
-	for (sector = first; sector <= last; sector++)
+	for (unsigned int sector = first; sector <= last; sector++)
 		bank->sectors[sector].is_protected = set;
 	return ERROR_OK;
 }
@@ -402,7 +388,6 @@ static int stmsmi_write(struct flash_bank *bank, const uint8_t *buffer,
 	struct stmsmi_flash_bank *stmsmi_info = bank->driver_priv;
 	uint32_t io_base = stmsmi_info->io_base;
 	uint32_t cur_count, page_size, page_offset;
-	int sector;
 	int retval = ERROR_OK;
 
 	LOG_DEBUG("%s: offset=0x%08" PRIx32 " count=0x%08" PRIx32,
@@ -419,19 +404,21 @@ static int stmsmi_write(struct flash_bank *bank, const uint8_t *buffer,
 	}
 
 	/* Check sector protection */
-	for (sector = 0; sector < bank->num_sectors; sector++) {
+	for (unsigned int sector = 0; sector < bank->num_sectors; sector++) {
 		/* Start offset in or before this sector? */
 		/* End offset in or behind this sector? */
 		if ((offset <
 				(bank->sectors[sector].offset + bank->sectors[sector].size))
 			&& ((offset + count - 1) >= bank->sectors[sector].offset)
 			&& bank->sectors[sector].is_protected) {
-			LOG_ERROR("Flash sector %d protected", sector);
+			LOG_ERROR("Flash sector %u protected", sector);
 			return ERROR_FAIL;
 		}
 	}
 
-	page_size = stmsmi_info->dev->pagesize;
+	/* if no valid page_size, use reasonable default */
+	page_size = stmsmi_info->dev->pagesize ?
+		stmsmi_info->dev->pagesize : SPIFLASH_DEF_PAGESIZE;
 
 	/* unaligned buffer head */
 	if (count > 0 && (offset & 3) != 0) {
@@ -524,7 +511,7 @@ static int stmsmi_probe(struct flash_bank *bank)
 {
 	struct target *target = bank->target;
 	struct stmsmi_flash_bank *stmsmi_info = bank->driver_priv;
-	uint32_t io_base;
+	uint32_t io_base, sectorsize;
 	struct flash_sector *sectors;
 	uint32_t id = 0; /* silence uninitialized warning */
 	const struct stmsmi_target *target_device;
@@ -532,7 +519,7 @@ static int stmsmi_probe(struct flash_bank *bank)
 
 	if (stmsmi_info->probed)
 		free(bank->sectors);
-	stmsmi_info->probed = 0;
+	stmsmi_info->probed = false;
 
 	for (target_device = target_devices ; target_device->name ; ++target_device)
 		if (target_device->tap_idcode == target->tap->idcode)
@@ -557,13 +544,13 @@ static int stmsmi_probe(struct flash_bank *bank)
 			stmsmi_info->bank_num = SMI_SEL_BANK3;
 			break;
 		default:
-			LOG_ERROR("Invalid SMI base address 0x%" PRIx32, bank->base);
+			LOG_ERROR("Invalid SMI base address " TARGET_ADDR_FMT, bank->base);
 			return ERROR_FAIL;
 	}
 	io_base = target_device->io_base;
 	stmsmi_info->io_base = io_base;
 
-	LOG_DEBUG("Valid SMI on device %s at address 0x%" PRIx32,
+	LOG_DEBUG("Valid SMI on device %s at address " TARGET_ADDR_FMT,
 		target_device->name, bank->base);
 
 	/* read and decode flash ID; returns in SW mode */
@@ -589,25 +576,33 @@ static int stmsmi_probe(struct flash_bank *bank)
 
 	/* Set correct size value */
 	bank->size = stmsmi_info->dev->size_in_bytes;
+	if (bank->size <= (1UL << 16))
+		LOG_WARNING("device needs 2-byte addresses - not implemented");
+	if (bank->size > (1UL << 24))
+		LOG_WARNING("device needs paging or 4-byte addresses - not implemented");
+
+	/* if no sectors, treat whole bank as single sector */
+	sectorsize = stmsmi_info->dev->sectorsize ?
+		stmsmi_info->dev->sectorsize : stmsmi_info->dev->size_in_bytes;
 
 	/* create and fill sectors array */
 	bank->num_sectors =
-		stmsmi_info->dev->size_in_bytes / stmsmi_info->dev->sectorsize;
+		stmsmi_info->dev->size_in_bytes / sectorsize;
 	sectors = malloc(sizeof(struct flash_sector) * bank->num_sectors);
-	if (sectors == NULL) {
+	if (!sectors) {
 		LOG_ERROR("not enough memory");
 		return ERROR_FAIL;
 	}
 
-	for (int sector = 0; sector < bank->num_sectors; sector++) {
-		sectors[sector].offset = sector * stmsmi_info->dev->sectorsize;
-		sectors[sector].size = stmsmi_info->dev->sectorsize;
+	for (unsigned int sector = 0; sector < bank->num_sectors; sector++) {
+		sectors[sector].offset = sector * sectorsize;
+		sectors[sector].size = sectorsize;
 		sectors[sector].is_erased = -1;
 		sectors[sector].is_protected = 1;
 	}
 
 	bank->sectors = sectors;
-	stmsmi_info->probed = 1;
+	stmsmi_info->probed = true;
 	return ERROR_OK;
 }
 
@@ -625,24 +620,23 @@ static int stmsmi_protect_check(struct flash_bank *bank)
 	return ERROR_OK;
 }
 
-static int get_stmsmi_info(struct flash_bank *bank, char *buf, int buf_size)
+static int get_stmsmi_info(struct flash_bank *bank, struct command_invocation *cmd)
 {
 	struct stmsmi_flash_bank *stmsmi_info = bank->driver_priv;
 
 	if (!(stmsmi_info->probed)) {
-		snprintf(buf, buf_size,
-			"\nSMI flash bank not probed yet\n");
+		command_print_sameline(cmd, "\nSMI flash bank not probed yet\n");
 		return ERROR_OK;
 	}
 
-	snprintf(buf, buf_size, "\nSMI flash information:\n"
+	command_print_sameline(cmd, "\nSMI flash information:\n"
 		"  Device \'%s\' (ID 0x%08" PRIx32 ")\n",
 		stmsmi_info->dev->name, stmsmi_info->dev->device_id);
 
 	return ERROR_OK;
 }
 
-struct flash_driver stmsmi_flash = {
+const struct flash_driver stmsmi_flash = {
 	.name = "stmsmi",
 	.flash_bank_command = stmsmi_flash_bank_command,
 	.erase = stmsmi_erase,
@@ -654,4 +648,5 @@ struct flash_driver stmsmi_flash = {
 	.erase_check = default_flash_blank_check,
 	.protect_check = stmsmi_protect_check,
 	.info = get_stmsmi_info,
+	.free_driver_priv = default_flash_free_driver_priv,
 };
