@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2007 by Dominic Rath                                    *
  *   Dominic.Rath@gmx.de                                                   *
@@ -7,19 +9,6 @@
  *                                                                         *
  *   Copyright (C) 2008 by Spencer Oliver                                  *
  *   spen@spen-soft.co.uk                                                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +18,7 @@
 #include "log.h"
 #include "configuration.h"
 #include "fileio.h"
+#include "replacements.h"
 
 struct fileio {
 	char *url;
@@ -153,6 +143,11 @@ int fileio_close(struct fileio *fileio)
 	return retval;
 }
 
+int fileio_feof(struct fileio *fileio)
+{
+	return feof(fileio->file);
+}
+
 int fileio_seek(struct fileio *fileio, size_t position)
 {
 	int retval;
@@ -192,9 +187,9 @@ int fileio_read_u32(struct fileio *fileio, uint32_t *data)
 
 	retval = fileio_local_read(fileio, sizeof(uint32_t), buf, &size_read);
 
-	if (ERROR_OK == retval && sizeof(uint32_t) != size_read)
+	if (retval == ERROR_OK && sizeof(uint32_t) != size_read)
 		retval = -EIO;
-	if (ERROR_OK == retval)
+	if (retval == ERROR_OK)
 		*data = be_to_h_u32(buf);
 
 	return retval;
@@ -202,7 +197,7 @@ int fileio_read_u32(struct fileio *fileio, uint32_t *data)
 
 static int fileio_local_fgets(struct fileio *fileio, size_t size, void *buffer)
 {
-	if (fgets(buffer, size, fileio->file) == NULL)
+	if (!fgets(buffer, size, fileio->file))
 		return ERROR_FILEIO_OPERATION_FAILED;
 
 	return ERROR_OK;
@@ -246,7 +241,7 @@ int fileio_write_u32(struct fileio *fileio, uint32_t data)
 
 	retval = fileio_write(fileio, 4, buf, &size_written);
 
-	if (ERROR_OK == retval && size_written != sizeof(uint32_t))
+	if (retval == ERROR_OK && size_written != sizeof(uint32_t))
 		retval = -EIO;
 
 	return retval;
