@@ -1,31 +1,20 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2013 by Andes Technology                                *
  *   Hsiangkai Wang <hkwang@andestech.com>                                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include <jtag/adapter.h>
 #include <jtag/interface.h>
 #include <jtag/commands.h>
 #include <transport/transport.h>
 #include <target/target.h>
 #include <jtag/aice/aice_transport.h>
-#include <jtag/drivers/libusb_common.h>
 #include "aice_usb.h"
 
 #define AICE_KHZ_TO_SPEED_MAP_SIZE	16
@@ -122,7 +111,7 @@ int aice_init_targets(void)
  */
 static int aice_init(void)
 {
-	if (ERROR_OK != aice_port->api->open(&param)) {
+	if (aice_port->api->open(&param) != ERROR_OK) {
 		LOG_ERROR("Cannot find AICE Interface! Please check "
 				"connection and permissions.");
 		return ERROR_JTAG_INIT_FAILED;
@@ -150,7 +139,7 @@ static int aice_execute_reset(struct jtag_command *cmd)
 	static int last_trst;
 	int retval = ERROR_OK;
 
-	DEBUG_JTAG_IO("reset trst: %d", cmd->cmd.reset->trst);
+	LOG_DEBUG_IO("reset trst: %d", cmd->cmd.reset->trst);
 
 	if (cmd->cmd.reset->trst != last_trst) {
 		if (cmd->cmd.reset->trst)
@@ -218,7 +207,7 @@ static int aice_khz(int khz, int *jtag_speed)
 	int i;
 	for (i = 0 ; i < AICE_KHZ_TO_SPEED_MAP_SIZE ; i++) {
 		if (khz == aice_khz_to_speed_map[i]) {
-			if (8 <= i)
+			if (i >= 8)
 				*jtag_speed = i | AICE_TCK_CONTROL_TCK3048;
 			else
 				*jtag_speed = i;
@@ -239,16 +228,40 @@ static int aice_khz(int khz, int *jtag_speed)
 	return ERROR_OK;
 }
 
+int aice_scan_jtag_chain(void)
+{
+	LOG_DEBUG("=== %s ===", __func__);
+	uint8_t num_of_idcode = 0;
+	struct target *target;
+
+	int res = aice_port->api->idcode(aice_target_id_codes, &num_of_idcode);
+	if (res != ERROR_OK) {
+		LOG_ERROR("<-- TARGET ERROR! Failed to identify AndesCore "
+					"JTAG Manufacture ID in the JTAG scan chain. "
+					"Failed to access EDM registers. -->");
+		return res;
+	}
+
+	for (unsigned int i = 0; i < num_of_idcode; i++)
+		LOG_DEBUG("id_codes[%u] = 0x%" PRIx32, i, aice_target_id_codes[i]);
+
+	/* Update tap idcode */
+	for (target = all_targets; target; target = target->next)
+		target->tap->idcode = aice_target_id_codes[target->tap->abs_chain_position];
+
+	return ERROR_OK;
+}
+
 /***************************************************************************/
 /* Command handlers */
 COMMAND_HANDLER(aice_handle_aice_info_command)
 {
 	LOG_DEBUG("aice_handle_aice_info_command");
 
-	command_print(CMD_CTX, "Description: %s", param.device_desc);
-	command_print(CMD_CTX, "Serial number: %s", param.serial);
+	command_print(CMD, "Description: %s", param.device_desc);
+	command_print(CMD, "Serial number: %s", adapter_get_required_serial());
 	if (strncmp(aice_port->name, "aice_pipe", 9) == 0)
-		command_print(CMD_CTX, "Adapter: %s", param.adapter_name);
+		command_print(CMD, "Adapter: %s", param.adapter_name);
 
 	return ERROR_OK;
 }
@@ -285,18 +298,6 @@ COMMAND_HANDLER(aice_handle_aice_desc_command)
 	return ERROR_OK;
 }
 
-COMMAND_HANDLER(aice_handle_aice_serial_command)
-{
-	LOG_DEBUG("aice_handle_aice_serial_command");
-
-	if (CMD_ARGC == 1)
-		param.serial = strdup(CMD_ARGV[0]);
-	else
-		LOG_ERROR("expected exactly one argument to aice serial <serial-number>");
-
-	return ERROR_OK;
-}
-
 COMMAND_HANDLER(aice_handle_aice_vid_pid_command)
 {
 	LOG_DEBUG("aice_handle_aice_vid_pid_command");
@@ -399,83 +400,76 @@ static const struct command_registration aice_subcommand_handlers[] = {
 		.handler = &aice_handle_aice_info_command,
 		.mode = COMMAND_EXEC,
 		.help = "show aice info",
-		.usage = "aice info",
+		.usage = "",
 	},
 	{
 		.name = "port",
 		.handler = &aice_handle_aice_port_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set the port of the AICE",
-		.usage = "aice port ['aice_pipe'|'aice_usb']",
+		.usage = "['aice_pipe'|'aice_usb']",
 	},
 	{
 		.name = "desc",
 		.handler = &aice_handle_aice_desc_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set the aice device description",
-		.usage = "aice desc [desciption string]",
-	},
-	{
-		.name = "serial",
-		.handler = &aice_handle_aice_serial_command,
-		.mode = COMMAND_CONFIG,
-		.help = "set the serial number of the AICE device",
-		.usage = "aice serial [serial string]",
+		.usage = "[description string]",
 	},
 	{
 		.name = "vid_pid",
 		.handler = &aice_handle_aice_vid_pid_command,
 		.mode = COMMAND_CONFIG,
 		.help = "the vendor and product ID of the AICE device",
-		.usage = "aice vid_pid (vid pid)*",
+		.usage = "(vid pid)*",
 	},
 	{
 		.name = "adapter",
 		.handler = &aice_handle_aice_adapter_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set the file name of adapter",
-		.usage = "aice adapter [adapter name]",
+		.usage = "[adapter name]",
 	},
 	{
 		.name = "retry_times",
 		.handler = &aice_handle_aice_retry_times_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set retry times as AICE timeout",
-		.usage = "aice retry_times num_of_retry",
+		.usage = "num_of_retry",
 	},
 	{
 		.name = "count_to_check_dbger",
 		.handler = &aice_handle_aice_count_to_check_dbger_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set retry times as checking $DBGER status",
-		.usage = "aice count_to_check_dbger count_of_checking",
+		.usage = "count_of_checking",
 	},
 	{
 		.name = "custom_srst_script",
 		.handler = &aice_handle_aice_custom_srst_script_command,
 		.mode = COMMAND_CONFIG,
-		.usage = "custom_srst_script script_file_name",
+		.usage = "script_file_name",
 		.help = "set custom srst script",
 	},
 	{
 		.name = "custom_trst_script",
 		.handler = &aice_handle_aice_custom_trst_script_command,
 		.mode = COMMAND_CONFIG,
-		.usage = "custom_trst_script script_file_name",
+		.usage = "script_file_name",
 		.help = "set custom trst script",
 	},
 	{
 		.name = "custom_restart_script",
 		.handler = &aice_handle_aice_custom_restart_script_command,
 		.mode = COMMAND_CONFIG,
-		.usage = "custom_restart_script script_file_name",
+		.usage = "script_file_name",
 		.help = "set custom restart script",
 	},
 	{
 		.name = "reset",
 		.handler = &aice_handle_aice_reset_command,
 		.mode = COMMAND_EXEC,
-		.usage = "aice reset",
+		.usage = "",
 		.help = "reset AICE",
 	},
 	COMMAND_REGISTRATION_DONE
@@ -486,7 +480,7 @@ static const struct command_registration aice_command_handlers[] = {
 		.name = "aice",
 		.mode = COMMAND_ANY,
 		.help = "perform aice management",
-		.usage = "aice [subcommand]",
+		.usage = "[subcommand]",
 		.chain = aice_subcommand_handlers,
 	},
 	COMMAND_REGISTRATION_DONE
@@ -494,14 +488,20 @@ static const struct command_registration aice_command_handlers[] = {
 /***************************************************************************/
 /* End of Command handlers */
 
-struct jtag_interface aice_interface = {
+static struct jtag_interface aice_interface = {
+	.execute_queue = aice_execute_queue,
+};
+
+struct adapter_driver aice_adapter_driver = {
 	.name = "aice",
-	.commands = aice_command_handlers,
 	.transports = aice_transports,
+	.commands = aice_command_handlers,
+
 	.init = aice_init,
 	.quit = aice_quit,
-	.execute_queue = aice_execute_queue,
 	.speed = aice_speed,		/* set interface speed */
-	.speed_div = aice_speed_div,	/* return readable value */
 	.khz = aice_khz,		/* convert khz to interface speed value */
+	.speed_div = aice_speed_div,	/* return readable value */
+
+	.jtag_ops = &aice_interface,
 };
