@@ -1,19 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2006 by Anders Larsen                                   *
  *   al@alarsen.net                                                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -209,7 +198,7 @@ static int at91rm9200_init(void)
 
 	cur_device = devices;
 
-	if (at91rm9200_device == NULL || at91rm9200_device[0] == 0) {
+	if (!at91rm9200_device || at91rm9200_device[0] == 0) {
 		at91rm9200_device = "rea_ecr";
 		LOG_WARNING("No at91rm9200 device specified, using default 'rea_ecr'");
 	}
