@@ -17,6 +17,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -27,7 +31,9 @@
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #endif
+#ifdef HAVE_LIBUSB
 #include <libusb.h>
+#endif
 
 #include "libjaylink.h"
 #include "libjaylink-internal.h"
@@ -43,6 +49,7 @@
 #define CMD_GET_HW_STATUS	0x07
 #define CMD_REGISTER		0x09
 #define CMD_GET_HW_INFO		0xc1
+#define CMD_GET_COUNTERS	0xc2
 #define CMD_GET_FREE_MEMORY	0xd4
 #define CMD_GET_CAPS		0xe8
 #define CMD_GET_EXT_CAPS	0xed
@@ -61,6 +68,9 @@
 #define REG_MAX_SIZE		0x200
 /** Size of a connection entry in bytes. */
 #define REG_CONN_INFO_SIZE	16
+
+/* The maximum path depth according to the USB 3.0 specification. */
+#define MAX_USB_PATH_DEPTH	7
 /** @endcond */
 
 /** @private */
@@ -86,7 +96,6 @@ JAYLINK_PRIV struct jaylink_device *device_allocate(
 
 	dev->ctx = ctx;
 	dev->ref_count = 1;
-	dev->usb_dev = NULL;
 
 	return dev;
 }
@@ -132,7 +141,6 @@ JAYLINK_API int jaylink_get_devices(struct jaylink_context *ctx,
 	struct list *item;
 	struct jaylink_device **tmp;
 	struct jaylink_device *dev;
-	size_t i;
 
 	if (!ctx || !devs)
 		return JAYLINK_ERR_ARG;
@@ -141,13 +149,13 @@ JAYLINK_API int jaylink_get_devices(struct jaylink_context *ctx,
 	tmp = allocate_device_list(num);
 
 	if (!tmp) {
-		log_err(ctx, "Failed to allocate device list.");
+		log_err(ctx, "Failed to allocate device list");
 		return JAYLINK_ERR_MALLOC;
 	}
 
 	item = ctx->discovered_devs;
 
-	for (i = 0; i < num; i++) {
+	for (size_t i = 0; i < num; i++) {
 		dev = (struct jaylink_device *)item->data;
 		tmp[i] = jaylink_ref_device(dev);
 		item = item->next;
@@ -174,13 +182,11 @@ JAYLINK_API int jaylink_get_devices(struct jaylink_context *ctx,
  */
 JAYLINK_API void jaylink_free_devices(struct jaylink_device **devs, bool unref)
 {
-	size_t i;
-
 	if (!devs)
 		return;
 
 	if (unref) {
-		for (i = 0; devs[i]; i++)
+		for (size_t i = 0; devs[i]; i++)
 			jaylink_unref_device(devs[i]);
 	}
 
@@ -206,7 +212,7 @@ JAYLINK_API int jaylink_device_get_host_interface(
 	if (!dev || !iface)
 		return JAYLINK_ERR_ARG;
 
-	*iface = dev->interface;
+	*iface = dev->iface;
 
 	return JAYLINK_OK;
 }
@@ -233,7 +239,7 @@ JAYLINK_API int jaylink_device_get_serial_number(
 	if (!dev || !serial_number)
 		return JAYLINK_ERR_ARG;
 
-	if (!dev->valid_serial_number)
+	if (!dev->has_serial_number)
 		return JAYLINK_ERR_NOT_AVAILABLE;
 
 	*serial_number = dev->serial_number;
@@ -253,7 +259,8 @@ JAYLINK_API int jaylink_device_get_serial_number(
  *
  * @retval JAYLINK_OK Success.
  * @retval JAYLINK_ERR_ARG Invalid arguments.
- * @retval JAYLINK_ERR_NOT_SUPPORTED Operation not supported.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_USB only.
  *
  * @see jaylink_device_get_serial_number()
  *
@@ -266,11 +273,236 @@ JAYLINK_API int jaylink_device_get_usb_address(
 	if (!dev || !address)
 		return JAYLINK_ERR_ARG;
 
-	if (dev->interface != JAYLINK_HIF_USB)
+	if (dev->iface != JAYLINK_HIF_USB)
 		return JAYLINK_ERR_NOT_SUPPORTED;
 
+#ifdef HAVE_LIBUSB
 	*address = dev->usb_address;
 
+	return JAYLINK_OK;
+#else
+	return JAYLINK_ERR_NOT_SUPPORTED;
+#endif
+}
+
+/**
+ * Get the USB bus and port numbers of a device.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] bus The bus number of the device on success and undefined on
+ *                 failure.
+ * @param[out] ports Newly allocated array which contains the port numbers on
+ *                   success and is undefined on failure. The array must be
+ *                   free'd by the caller.
+ * @param[out] length Length of the port array on success and undefined on
+ *                    failure.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_MALLOC Memory allocation error.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_USB only.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_usb_bus_ports(
+		const struct jaylink_device *dev, uint8_t *bus,
+		uint8_t **ports, size_t *length)
+{
+	if (!dev || !bus || !ports || !length)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_USB)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+#ifdef HAVE_LIBUSB
+	struct jaylink_context *ctx = dev->ctx;
+	int ret;
+
+	*ports = malloc(MAX_USB_PATH_DEPTH * sizeof(uint8_t));
+
+	if (!*ports) {
+		return JAYLINK_ERR_MALLOC;
+	}
+
+	ret = libusb_get_port_numbers(dev->usb_dev, *ports,
+		MAX_USB_PATH_DEPTH);
+
+	if (ret == LIBUSB_ERROR_OVERFLOW) {
+		log_err(ctx, "Failed to get port numbers: %s",
+			libusb_error_name(ret));
+		return JAYLINK_ERR_ARG;
+	}
+
+	*length = ret;
+	*bus = libusb_get_bus_number(dev->usb_dev);
+
+	return JAYLINK_OK;
+#else
+	return JAYLINK_ERR_NOT_SUPPORTED;
+#endif
+}
+
+/**
+ * Get the IPv4 address string of a device.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] address IPv4 address string in quad-dotted decimal format of the
+ *                     device on success and undefined on failure.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_TCP only.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_ipv4_address(
+		const struct jaylink_device *dev, char *address)
+{
+	if (!dev || !address)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_TCP)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+	memcpy(address, dev->ipv4_address, sizeof(dev->ipv4_address));
+
+	return JAYLINK_OK;
+}
+
+/**
+ * Get the MAC address of a device.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] address MAC address of the device on success and undefined on
+ *                     failure. The length of the MAC address is
+ *                     #JAYLINK_MAC_ADDRESS_LENGTH bytes.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_TCP only.
+ * @retval JAYLINK_ERR_NOT_AVAILABLE MAC address is not available.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_mac_address(
+		const struct jaylink_device *dev, uint8_t *address)
+{
+	if (!dev || !address)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_TCP)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+	if (!dev->has_mac_address)
+		return JAYLINK_ERR_NOT_AVAILABLE;
+
+	memcpy(address, dev->mac_address, sizeof(dev->mac_address));
+
+	return JAYLINK_OK;
+}
+
+/**
+ * Get the hardware version of a device.
+ *
+ * @note The hardware type can not be obtained by this function, use
+ *       jaylink_get_hardware_version() instead.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] version Hardware version of the device on success and undefined
+ *                     on failure.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_TCP only.
+ * @retval JAYLINK_ERR_NOT_AVAILABLE Hardware version is not available.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_hardware_version(
+		const struct jaylink_device *dev,
+		struct jaylink_hardware_version *version)
+{
+	if (!dev || !version)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_TCP)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+	if (!dev->has_hw_version)
+		return JAYLINK_ERR_NOT_AVAILABLE;
+
+	*version = dev->hw_version;
+
+	return JAYLINK_OK;
+}
+
+/**
+ * Get the product name of a device.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] name Product name of the device on success and undefined on
+ *                  failure. The maximum length of the product name is
+ *                  #JAYLINK_PRODUCT_NAME_MAX_LENGTH bytes.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_TCP only.
+ * @retval JAYLINK_ERR_NOT_AVAILABLE Product name is not available.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_product_name(
+		const struct jaylink_device *dev, char *name)
+{
+	if (!dev || !name)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_TCP)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+	if (!dev->has_product_name)
+		return JAYLINK_ERR_NOT_AVAILABLE;
+
+	memcpy(name, dev->product_name, sizeof(dev->product_name));
+
+	return JAYLINK_OK;
+}
+
+/**
+ * Get the nickname of a device.
+ *
+ * @param[in] dev Device instance.
+ * @param[out] nickname Nickname of the device on success and undefined on
+ *                      failure. The maximum length of the nickname is
+ *                      #JAYLINK_NICKNAME_MAX_LENGTH bytes.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_NOT_SUPPORTED Supported for devices with host interface
+ *                                   #JAYLINK_HIF_TCP only.
+ * @retval JAYLINK_ERR_NOT_AVAILABLE Nickname is not available.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_device_get_nickname(const struct jaylink_device *dev,
+		char *nickname)
+{
+	if (!dev || !nickname)
+		return JAYLINK_ERR_ARG;
+
+	if (dev->iface != JAYLINK_HIF_TCP)
+		return JAYLINK_ERR_NOT_SUPPORTED;
+
+	if (!dev->has_nickname)
+		return JAYLINK_ERR_NOT_AVAILABLE;
+
+	memcpy(nickname, dev->nickname, sizeof(dev->nickname));
+
 	return JAYLINK_OK;
 }
 
@@ -312,15 +544,24 @@ JAYLINK_API void jaylink_unref_device(struct jaylink_device *dev)
 
 	if (!dev->ref_count) {
 		ctx = dev->ctx;
-
-		log_dbg(ctx, "Device destroyed (bus:address = %03u:%03u).",
-			libusb_get_bus_number(dev->usb_dev),
-			libusb_get_device_address(dev->usb_dev));
-
 		ctx->devs = list_remove(dev->ctx->devs, dev);
 
-		if (dev->usb_dev)
+		if (dev->iface == JAYLINK_HIF_USB) {
+#ifdef HAVE_LIBUSB
+			log_dbg(ctx, "Device destroyed (bus:address = "
+				"%03u:%03u)",
+				libusb_get_bus_number(dev->usb_dev),
+				libusb_get_device_address(dev->usb_dev));
+
 			libusb_unref_device(dev->usb_dev);
+#endif
+		} else if (dev->iface == JAYLINK_HIF_TCP) {
+			log_dbg(ctx, "Device destroyed (IPv4 address = %s)",
+				dev->ipv4_address);
+		} else {
+			log_err(ctx, "BUG: Invalid host interface: %u",
+				dev->iface);
+		}
 
 		free(dev);
 	}
@@ -375,7 +616,7 @@ JAYLINK_API int jaylink_open(struct jaylink_device *dev,
 	handle = allocate_device_handle(dev);
 
 	if (!handle) {
-		log_err(dev->ctx, "Device handle malloc failed.");
+		log_err(dev->ctx, "Device handle malloc failed");
 		return JAYLINK_ERR_MALLOC;
 	}
 
@@ -473,7 +714,7 @@ JAYLINK_API int jaylink_get_firmware_version(
 	ret = transport_start_write_read(devh, 1, 2, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -483,7 +724,7 @@ JAYLINK_API int jaylink_get_firmware_version(
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -491,7 +732,7 @@ JAYLINK_API int jaylink_get_firmware_version(
 	ret = transport_read(devh, buf, 2);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -505,7 +746,7 @@ JAYLINK_API int jaylink_get_firmware_version(
 	ret = transport_start_read(devh, dummy);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_read() failed: %s.",
+		log_err(ctx, "transport_start_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -513,14 +754,14 @@ JAYLINK_API int jaylink_get_firmware_version(
 	tmp = malloc(dummy);
 
 	if (!tmp) {
-		log_err(ctx, "Firmware version string malloc failed.");
+		log_err(ctx, "Firmware version string malloc failed");
 		return JAYLINK_ERR_MALLOC;
 	}
 
 	ret = transport_read(devh, (uint8_t *)tmp, dummy);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		free(tmp);
 		return ret;
@@ -563,7 +804,6 @@ JAYLINK_API int jaylink_get_hardware_info(struct jaylink_device_handle *devh,
 	int ret;
 	struct jaylink_context *ctx;
 	uint8_t buf[5];
-	unsigned int i;
 	unsigned int num;
 	unsigned int length;
 
@@ -573,7 +813,7 @@ JAYLINK_API int jaylink_get_hardware_info(struct jaylink_device_handle *devh,
 	ctx = devh->dev->ctx;
 	num = 0;
 
-	for (i = 0; i < 32; i++) {
+	for (unsigned int i = 0; i < 32; i++) {
 		if (mask & (1 << i))
 			num++;
 	}
@@ -583,7 +823,7 @@ JAYLINK_API int jaylink_get_hardware_info(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 5, length, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -594,7 +834,7 @@ JAYLINK_API int jaylink_get_hardware_info(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 5);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -602,18 +842,96 @@ JAYLINK_API int jaylink_get_hardware_info(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, (uint8_t *)info, length);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
 
-	for (i = 0; i < num; i++)
+	for (unsigned int i = 0; i < num; i++)
 		info[i] = buffer_get_u32((uint8_t *)info,
 			i * sizeof(uint32_t));
 
 	return JAYLINK_OK;
 }
 
+/**
+ * Retrieve the counter values of a device.
+ *
+ * @note This function must only be used if the device has the
+ *       #JAYLINK_DEV_CAP_GET_COUNTERS capability.
+ *
+ * @param[in,out] devh Device handle.
+ * @param[in] mask A bit field where each set bit represents a counter value to
+ *                 request. See #jaylink_counter for a description of the
+ *                 counters and their bit positions.
+ * @param[out] values Array to store the counter values on success. Its content
+ *                    is undefined on failure. The array must be large enough
+ *                    to contain at least as many elements as bits set in @p
+ *                    mask.
+ *
+ * @retval JAYLINK_OK Success.
+ * @retval JAYLINK_ERR_ARG Invalid arguments.
+ * @retval JAYLINK_ERR_TIMEOUT A timeout occurred.
+ * @retval JAYLINK_ERR_IO Input/output error.
+ * @retval JAYLINK_ERR Other error conditions.
+ *
+ * @since 0.2.0
+ */
+JAYLINK_API int jaylink_get_counters(struct jaylink_device_handle *devh,
+		uint32_t mask, uint32_t *values)
+{
+	int ret;
+	struct jaylink_context *ctx;
+	uint8_t buf[5];
+	unsigned int num;
+	unsigned int length;
+
+	if (!devh || !mask || !values)
+		return JAYLINK_ERR_ARG;
+
+	ctx = devh->dev->ctx;
+	num = 0;
+
+	for (unsigned int i = 0; i < 32; i++) {
+		if (mask & (1 << i))
+			num++;
+	}
+
+	length = num * sizeof(uint32_t);
+	ret = transport_start_write_read(devh, 5, length, true);
+
+	if (ret != JAYLINK_OK) {
+		log_err(ctx, "transport_start_write_read() failed: %s",
+			jaylink_strerror(ret));
+		return ret;
+	}
+
+	buf[0] = CMD_GET_COUNTERS;
+	buffer_set_u32(buf, mask, 1);
+
+	ret = transport_write(devh, buf, 5);
+
+	if (ret != JAYLINK_OK) {
+		log_err(ctx, "transport_write() failed: %s",
+			jaylink_strerror(ret));
+		return ret;
+	}
+
+	ret = transport_read(devh, (uint8_t *)values, length);
+
+	if (ret != JAYLINK_OK) {
+		log_err(ctx, "transport_read() failed: %s",
+			jaylink_strerror(ret));
+		return ret;
+	}
+
+	for (unsigned int i = 0; i < num; i++)
+		values[i] = buffer_get_u32((uint8_t *)values,
+			i * sizeof(uint32_t));
+
+	return JAYLINK_OK;
+}
+
 /**
  * Retrieve the hardware version of a device.
  *
@@ -651,7 +969,7 @@ JAYLINK_API int jaylink_get_hardware_version(
 	ret = transport_start_write_read(devh, 1, 4, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -661,7 +979,7 @@ JAYLINK_API int jaylink_get_hardware_version(
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -669,7 +987,7 @@ JAYLINK_API int jaylink_get_hardware_version(
 	ret = transport_read(devh, buf, 4);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -712,7 +1030,7 @@ JAYLINK_API int jaylink_get_hardware_status(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 1, 8, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -722,7 +1040,7 @@ JAYLINK_API int jaylink_get_hardware_status(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -730,7 +1048,7 @@ JAYLINK_API int jaylink_get_hardware_status(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, buf, 8);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -787,7 +1105,7 @@ JAYLINK_API int jaylink_get_caps(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 1, JAYLINK_DEV_CAPS_SIZE, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -797,7 +1115,7 @@ JAYLINK_API int jaylink_get_caps(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -805,7 +1123,7 @@ JAYLINK_API int jaylink_get_caps(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, caps, JAYLINK_DEV_CAPS_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -855,7 +1173,7 @@ JAYLINK_API int jaylink_get_extended_caps(struct jaylink_device_handle *devh,
 		true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -865,7 +1183,7 @@ JAYLINK_API int jaylink_get_extended_caps(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -873,7 +1191,7 @@ JAYLINK_API int jaylink_get_extended_caps(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, caps, JAYLINK_DEV_EXT_CAPS_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -913,7 +1231,7 @@ JAYLINK_API int jaylink_get_free_memory(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 1, 4, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -923,7 +1241,7 @@ JAYLINK_API int jaylink_get_free_memory(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -931,7 +1249,7 @@ JAYLINK_API int jaylink_get_free_memory(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, buf, 4);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -976,7 +1294,7 @@ JAYLINK_API int jaylink_read_raw_config(struct jaylink_device_handle *devh,
 		true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -986,7 +1304,7 @@ JAYLINK_API int jaylink_read_raw_config(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -994,7 +1312,7 @@ JAYLINK_API int jaylink_read_raw_config(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, config, JAYLINK_DEV_CONFIG_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1035,7 +1353,7 @@ JAYLINK_API int jaylink_write_raw_config(struct jaylink_device_handle *devh,
 	ret = transport_start_write(devh, 1 + JAYLINK_DEV_CONFIG_SIZE, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write() failed: %s.",
+		log_err(ctx, "transport_start_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1045,7 +1363,7 @@ JAYLINK_API int jaylink_write_raw_config(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 1);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1053,7 +1371,7 @@ JAYLINK_API int jaylink_write_raw_config(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, config, JAYLINK_DEV_CONFIG_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1064,13 +1382,12 @@ JAYLINK_API int jaylink_write_raw_config(struct jaylink_device_handle *devh,
 static void parse_conn_table(struct jaylink_connection *conns,
 		const uint8_t *buffer, uint16_t num, uint16_t entry_size)
 {
-	unsigned int i;
 	size_t offset;
 	struct in_addr in;
 
 	offset = 0;
 
-	for (i = 0; i < num; i++) {
+	for (unsigned int i = 0; i < num; i++) {
 		conns[i].pid = buffer_get_u32(buffer, offset);
 
 		in.s_addr = buffer_get_u32(buffer, offset + 4);
@@ -1140,7 +1457,6 @@ static bool _inet_pton(const char *str, struct in_addr *in)
  *         struct jaylink_connection conns[JAYLINK_MAX_CONNECTIONS];
  *         bool found_handle;
  *         size_t count;
- *         size_t i;
  *
  *         conn->handle = 0;
  *         conn->pid = 0;
@@ -1158,7 +1474,7 @@ static bool _inet_pton(const char *str, struct in_addr *in)
  *
  *         found_handle = false;
  *
- *         for (i = 0; i < count; i++) {
+ *         for (size_t i = 0; i < count; i++) {
  *                 if (conns[i].handle == conn->handle) {
  *                         found_handle = true;
  *                         break;
@@ -1232,7 +1548,7 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 14, REG_MIN_SIZE, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1240,7 +1556,7 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 14);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1248,7 +1564,7 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, buf, REG_MIN_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1260,12 +1576,12 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 
 	if (num > JAYLINK_MAX_CONNECTIONS) {
 		log_err(ctx, "Maximum number of device connections exceeded: "
-			"%u.", num);
+			"%u", num);
 		return JAYLINK_ERR_PROTO;
 	}
 
 	if (entry_size != REG_CONN_INFO_SIZE) {
-		log_err(ctx, "Invalid connection entry size: %u bytes.",
+		log_err(ctx, "Invalid connection entry size: %u bytes",
 			entry_size);
 		return JAYLINK_ERR_PROTO;
 	}
@@ -1275,7 +1591,7 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 
 	if (size > REG_MAX_SIZE) {
 		log_err(ctx, "Maximum registration information size exceeded: "
-			"%u bytes.", size);
+			"%u bytes", size);
 		return JAYLINK_ERR_PROTO;
 	}
 
@@ -1283,7 +1599,7 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 		ret = transport_start_read(devh, size - REG_MIN_SIZE);
 
 		if (ret != JAYLINK_OK) {
-			log_err(ctx, "transport_start_read() failed: %s.",
+			log_err(ctx, "transport_start_read() failed: %s",
 				jaylink_strerror(ret));
 			return JAYLINK_ERR;
 		}
@@ -1292,14 +1608,14 @@ JAYLINK_API int jaylink_register(struct jaylink_device_handle *devh,
 			size - REG_MIN_SIZE);
 
 		if (ret != JAYLINK_OK) {
-			log_err(ctx, "transport_read() failed: %s.",
+			log_err(ctx, "transport_read() failed: %s",
 				jaylink_strerror(ret));
 			return JAYLINK_ERR;
 		}
 	}
 
 	if (!handle) {
-		log_err(ctx, "Obtained invalid connection handle.");
+		log_err(ctx, "Obtained invalid connection handle");
 		return JAYLINK_ERR_PROTO;
 	}
 
@@ -1372,7 +1688,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 	ret = transport_start_write_read(devh, 14, REG_MIN_SIZE, true);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_start_write_read() failed: %s.",
+		log_err(ctx, "transport_start_write_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1380,7 +1696,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 	ret = transport_write(devh, buf, 14);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_write() failed: %s.",
+		log_err(ctx, "transport_write() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1388,7 +1704,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 	ret = transport_read(devh, buf, REG_MIN_SIZE);
 
 	if (ret != JAYLINK_OK) {
-		log_err(ctx, "transport_read() failed: %s.",
+		log_err(ctx, "transport_read() failed: %s",
 			jaylink_strerror(ret));
 		return ret;
 	}
@@ -1399,12 +1715,12 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 
 	if (num > JAYLINK_MAX_CONNECTIONS) {
 		log_err(ctx, "Maximum number of device connections exceeded: "
-			"%u.", num);
+			"%u", num);
 		return JAYLINK_ERR_PROTO;
 	}
 
 	if (entry_size != REG_CONN_INFO_SIZE) {
-		log_err(ctx, "Invalid connection entry size: %u bytes.",
+		log_err(ctx, "Invalid connection entry size: %u bytes",
 			entry_size);
 		return JAYLINK_ERR_PROTO;
 	}
@@ -1414,7 +1730,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 
 	if (size > REG_MAX_SIZE) {
 		log_err(ctx, "Maximum registration information size exceeded: "
-			"%u bytes.", size);
+			"%u bytes", size);
 		return JAYLINK_ERR_PROTO;
 	}
 
@@ -1422,7 +1738,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 		ret = transport_start_read(devh, size - REG_MIN_SIZE);
 
 		if (ret != JAYLINK_OK) {
-			log_err(ctx, "transport_start_read() failed: %s.",
+			log_err(ctx, "transport_start_read() failed: %s",
 				jaylink_strerror(ret));
 			return JAYLINK_ERR;
 		}
@@ -1431,7 +1747,7 @@ JAYLINK_API int jaylink_unregister(struct jaylink_device_handle *devh,
 			size - REG_MIN_SIZE);
 
 		if (ret != JAYLINK_OK) {
-			log_err(ctx, "transport_read() failed: %s.",
+			log_err(ctx, "transport_read() failed: %s",
 				jaylink_strerror(ret));
 			return JAYLINK_ERR;
 		}
