@@ -1,6 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /*******************************************************************************
  *   Driver for OpenJTAG Project (www.openjtag.org)                            *
- *   Compatible with libftdi and ftd2xx drivers.                               *
+ *   Compatible with libftdi drivers.                                          *
  *                                                                             *
  *   Cypress CY7C65215 support                                                 *
  *   Copyright (C) 2015 Vianney le Clément de Saint-Marcq, Essensium NV        *
@@ -18,19 +20,6 @@
  *   And jlink.c                                                               *
  *   Copyright (C) 2008 by Spencer Oliver                                      *
  *   spen@spen-soft.co.uk                                                      *
- *                                                                             *
- *   This program is free software; you can redistribute it and/or modify      *
- *   it under the terms of the GNU General Public License as published by      *
- *   the Free Software Foundation; either version 2 of the License, or         *
- *   (at your option) any later version.                                       *
- *                                                                             *
- *   This program is distributed in the hope that it will be useful,           *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- *   GNU General Public License for more details.                              *
- *                                                                             *
- *   You should have received a copy of the GNU General Public License         *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
  ***************************************************************************/
 
 /***************************************************************************
@@ -397,7 +386,7 @@ static int openjtag_init_standard(void)
 	uint8_t latency_timer;
 
 	/* Open by device description */
-	if (openjtag_device_desc == NULL) {
+	if (!openjtag_device_desc) {
 		LOG_WARNING("no openjtag device description specified, "
 				"using default 'Open JTAG Project'");
 		openjtag_device_desc = "Open JTAG Project";
@@ -449,7 +438,7 @@ static int openjtag_init_cy7c65215(void)
 	int ret;
 
 	usbh = NULL;
-	ret = jtag_libusb_open(cy7c65215_vids, cy7c65215_pids, NULL, &usbh, NULL);
+	ret = jtag_libusb_open(cy7c65215_vids, cy7c65215_pids, &usbh, NULL);
 	if (ret != ERROR_OK) {
 		LOG_ERROR("unable to open cy7c65215 device");
 		goto err;
@@ -475,7 +464,7 @@ static int openjtag_init_cy7c65215(void)
 	return ERROR_OK;
 
 err:
-	if (usbh != NULL)
+	if (usbh)
 		jtag_libusb_close(usbh);
 	return ERROR_JTAG_INIT_FAILED;
 }
@@ -803,7 +792,7 @@ static int openjtag_execute_queue(void)
 {
 	struct jtag_command *cmd = jtag_command_queue;
 
-	while (cmd != NULL) {
+	while (cmd) {
 		openjtag_execute_command(cmd);
 		cmd = cmd->next;
 	}
@@ -870,16 +859,16 @@ COMMAND_HANDLER(openjtag_handle_variant_command)
 	return ERROR_OK;
 }
 
-static const struct command_registration openjtag_command_handlers[] = {
+static const struct command_registration openjtag_subcommand_handlers[] = {
 	{
-		.name = "openjtag_device_desc",
+		.name = "device_desc",
 		.handler = openjtag_handle_device_desc_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set the USB device description of the OpenJTAG",
 		.usage = "description-string",
 	},
 	{
-		.name = "openjtag_variant",
+		.name = "variant",
 		.handler = openjtag_handle_variant_command,
 		.mode = COMMAND_CONFIG,
 		.help = "set the OpenJTAG variant",
@@ -888,6 +877,17 @@ static const struct command_registration openjtag_command_handlers[] = {
 	COMMAND_REGISTRATION_DONE
 };
 
+static const struct command_registration openjtag_command_handlers[] = {
+	{
+		.name = "openjtag",
+		.mode = COMMAND_ANY,
+		.help = "perform openjtag management",
+		.chain = openjtag_subcommand_handlers,
+		.usage = "",
+	},
+	COMMAND_REGISTRATION_DONE
+};
+
 static struct jtag_interface openjtag_interface = {
 	.execute_queue = openjtag_execute_queue,
 };
