@@ -1,28 +1,17 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2006 by Dominic Rath                                    *
  *   Dominic.Rath@gmx.de                                                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "pld.h"
 #include <helper/log.h>
+#include <helper/replacements.h>
 #include <helper/time_support.h>
 
 
@@ -30,8 +19,7 @@
  */
 extern struct pld_driver virtex2_pld;
 
-static struct pld_driver *pld_drivers[] =
-{
+static struct pld_driver *pld_drivers[] = {
 	&virtex2_pld,
 	NULL,
 };
@@ -43,12 +31,9 @@ struct pld_device *get_pld_device_by_num(int num)
 	struct pld_device *p;
 	int i = 0;
 
-	for (p = pld_devices; p; p = p->next)
-	{
+	for (p = pld_devices; p; p = p->next) {
 		if (i++ == num)
-		{
 			return p;
-		}
 	}
 
 	return NULL;
@@ -62,24 +47,17 @@ COMMAND_HANDLER(handle_pld_device_command)
 	int found = 0;
 
 	if (CMD_ARGC < 1)
-	{
-		LOG_WARNING("incomplete 'pld device' command");
-		return ERROR_OK;
-	}
+		return ERROR_COMMAND_SYNTAX_ERROR;
 
-	for (i = 0; pld_drivers[i]; i++)
-	{
-		if (strcmp(CMD_ARGV[0], pld_drivers[i]->name) == 0)
-		{
+	for (i = 0; pld_drivers[i]; i++) {
+		if (strcmp(CMD_ARGV[0], pld_drivers[i]->name) == 0) {
 			struct pld_device *p, *c;
 
 			/* register pld specific commands */
 			int retval;
 			if (pld_drivers[i]->commands) {
-				retval = register_commands(CMD_CTX, NULL,
-						pld_drivers[i]->commands);
-				if (ERROR_OK != retval)
-				{
+				retval = register_commands(CMD_CTX, NULL, pld_drivers[i]->commands);
+				if (retval != ERROR_OK) {
 					LOG_ERROR("couldn't register '%s' commands", CMD_ARGV[0]);
 					return ERROR_FAIL;
 				}
@@ -91,34 +69,29 @@ COMMAND_HANDLER(handle_pld_device_command)
 
 			retval = CALL_COMMAND_HANDLER(
 					pld_drivers[i]->pld_device_command, c);
-			if (ERROR_OK != retval)
-			{
+			if (retval != ERROR_OK) {
 				LOG_ERROR("'%s' driver rejected pld device",
-						CMD_ARGV[0]);
+					CMD_ARGV[0]);
 				free(c);
 				return ERROR_OK;
 			}
 
 			/* put pld device in linked list */
-			if (pld_devices)
-			{
+			if (pld_devices) {
 				/* find last pld device */
-				for (p = pld_devices; p && p->next; p = p->next);
+				for (p = pld_devices; p && p->next; p = p->next)
+					;
 				if (p)
 					p->next = c;
-			}
-			else
-			{
+			} else
 				pld_devices = c;
-			}
 
 			found = 1;
 		}
 	}
 
 	/* no matching pld driver found */
-	if (!found)
-	{
+	if (!found) {
 		LOG_ERROR("pld driver '%s' not found", CMD_ARGV[0]);
 		exit(-1);
 	}
@@ -131,16 +104,13 @@ COMMAND_HANDLER(handle_pld_devices_command)
 	struct pld_device *p;
 	int i = 0;
 
-	if (!pld_devices)
-	{
-		command_print(CMD_CTX, "no pld devices configured");
+	if (!pld_devices) {
+		command_print(CMD, "no pld devices configured");
 		return ERROR_OK;
 	}
 
 	for (p = pld_devices; p; p = p->next)
-	{
-		command_print(CMD_CTX, "#%i: %s", i++, p->driver->name);
-	}
+		command_print(CMD, "#%i: %s", i++, p->driver->name);
 
 	return ERROR_OK;
 }
@@ -154,35 +124,28 @@ COMMAND_HANDLER(handle_pld_load_command)
 	gettimeofday(&start, NULL);
 
 	if (CMD_ARGC < 2)
-	{
-		command_print(CMD_CTX, "usage: pld load <device#> <file>");
-		return ERROR_OK;
-	}
+		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	unsigned dev_id;
 	COMMAND_PARSE_NUMBER(uint, CMD_ARGV[0], dev_id);
 	p = get_pld_device_by_num(dev_id);
-	if (!p)
-	{
-		command_print(CMD_CTX, "pld device '#%s' is out of bounds", CMD_ARGV[0]);
+	if (!p) {
+		command_print(CMD, "pld device '#%s' is out of bounds", CMD_ARGV[0]);
 		return ERROR_OK;
 	}
 
-	if ((retval = p->driver->load(p, CMD_ARGV[1])) != ERROR_OK)
-	{
-		command_print(CMD_CTX, "failed loading file %s to pld device %u",
+	retval = p->driver->load(p, CMD_ARGV[1]);
+	if (retval != ERROR_OK) {
+		command_print(CMD, "failed loading file %s to pld device %u",
 			CMD_ARGV[1], dev_id);
-		switch (retval)
-		{
+		switch (retval) {
 		}
 		return retval;
-	}
-	else
-	{
+	} else {
 		gettimeofday(&end, NULL);
 		timeval_subtract(&duration, &end, &start);
 
-		command_print(CMD_CTX, "loaded file %s to pld device %u in %jis %jius",
+		command_print(CMD, "loaded file %s to pld device %u in %jis %jius",
 			CMD_ARGV[1], dev_id,
 			(intmax_t)duration.tv_sec, (intmax_t)duration.tv_usec);
 	}
@@ -196,6 +159,7 @@ static const struct command_registration pld_exec_command_handlers[] = {
 		.handler = handle_pld_devices_command,
 		.mode = COMMAND_EXEC,
 		.help = "list configured pld devices",
+		.usage = "",
 	},
 	{
 		.name = "load",
@@ -212,8 +176,7 @@ static int pld_init(struct command_context *cmd_ctx)
 	if (!pld_devices)
 		return ERROR_OK;
 
-	struct command *parent = command_find_in_context(cmd_ctx, "pld");
-	return register_commands(cmd_ctx, parent, pld_exec_command_handlers);
+	return register_commands(cmd_ctx, "pld", pld_exec_command_handlers);
 }
 
 COMMAND_HANDLER(handle_pld_init_command)
@@ -221,9 +184,8 @@ COMMAND_HANDLER(handle_pld_init_command)
 	if (CMD_ARGC != 0)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
-	static bool pld_initialized = false;
-	if (pld_initialized)
-	{
+	static bool pld_initialized;
+	if (pld_initialized) {
 		LOG_INFO("'pld init' has already been called");
 		return ERROR_OK;
 	}
@@ -246,6 +208,7 @@ static const struct command_registration pld_config_command_handlers[] = {
 		.mode = COMMAND_CONFIG,
 		.handler = handle_pld_init_command,
 		.help = "initialize PLD devices",
+		.usage = ""
 	},
 	COMMAND_REGISTRATION_DONE
 };
@@ -254,6 +217,7 @@ static const struct command_registration pld_command_handler[] = {
 		.name = "pld",
 		.mode = COMMAND_ANY,
 		.help = "programmable logic device commands",
+		.usage = "",
 		.chain = pld_config_command_handlers,
 	},
 	COMMAND_REGISTRATION_DONE
