@@ -1,19 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2011 by Broadcom Corporation                            *
  *   Evan Hunter - ehunter@broadcom.com                                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -27,27 +16,40 @@
 #include "server/gdb_server.h"
 
 /* RTOSs */
-extern struct rtos_type FreeRTOS_rtos;
-extern struct rtos_type ThreadX_rtos;
-extern struct rtos_type eCos_rtos;
-extern struct rtos_type Linux_os;
-extern struct rtos_type ChibiOS_rtos;
-extern struct rtos_type embKernel_rtos;
+extern struct rtos_type freertos_rtos;
+extern struct rtos_type threadx_rtos;
+extern struct rtos_type ecos_rtos;
+extern struct rtos_type linux_rtos;
+extern struct rtos_type chibios_rtos;
+extern struct rtos_type chromium_ec_rtos;
+extern struct rtos_type embkernel_rtos;
 extern struct rtos_type mqx_rtos;
-extern struct rtos_type uCOS_III_rtos;
+extern struct rtos_type ucos_iii_rtos;
+extern struct rtos_type nuttx_rtos;
+extern struct rtos_type hwthread_rtos;
+extern struct rtos_type riot_rtos;
+extern struct rtos_type zephyr_rtos;
 
 static struct rtos_type *rtos_types[] = {
-	&ThreadX_rtos,
-	&FreeRTOS_rtos,
-	&eCos_rtos,
-	&Linux_os,
-	&ChibiOS_rtos,
-	&embKernel_rtos,
+	&threadx_rtos,
+	&freertos_rtos,
+	&ecos_rtos,
+	&linux_rtos,
+	&chibios_rtos,
+	&chromium_ec_rtos,
+	&embkernel_rtos,
 	&mqx_rtos,
-	&uCOS_III_rtos,
+	&ucos_iii_rtos,
+	&nuttx_rtos,
+	&riot_rtos,
+	&zephyr_rtos,
+	/* keep this as last, as it always matches with rtos auto */
+	&hwthread_rtos,
 	NULL
 };
 
+static int rtos_try_next(struct target *target);
+
 int rtos_thread_packet(struct connection *connection, const char *packet, int packet_size);
 
 int rtos_smp_init(struct target *target)
@@ -57,6 +59,15 @@ int rtos_smp_init(struct target *target)
 	return ERROR_TARGET_INIT_FAILED;
 }
 
+static int rtos_target_for_threadid(struct connection *connection, int64_t threadid, struct target **t)
+{
+	struct target *curr = get_target_from_connection(connection);
+	if (t)
+		*t = curr;
+
+	return ERROR_OK;
+}
+
 static int os_alloc(struct target *target, struct rtos_type *ostype)
 {
 	struct rtos *os = target->rtos = calloc(1, sizeof(struct rtos));
@@ -72,6 +83,7 @@ static int os_alloc(struct target *target, struct rtos_type *ostype)
 
 	/* RTOS drivers can override the packet handler in _create(). */
 	os->gdb_thread_packet = rtos_thread_packet;
+	os->gdb_target_for_threadid = rtos_target_for_threadid;
 
 	return JIM_OK;
 }
@@ -81,9 +93,7 @@ static void os_free(struct target *target)
 	if (!target->rtos)
 		return;
 
-	if (target->rtos->symbols)
-		free(target->rtos->symbols);
-
+	free(target->rtos->symbols);
 	free(target->rtos);
 	target->rtos = NULL;
 }
@@ -92,7 +102,7 @@ static int os_alloc_create(struct target *target, struct rtos_type *ostype)
 {
 	int ret = os_alloc(target, ostype);
 
-	if (JIM_OK == ret) {
+	if (ret == JIM_OK) {
 		ret = target->rtos->type->create(target);
 		if (ret != JIM_OK)
 			os_free(target);
@@ -101,11 +111,11 @@ static int os_alloc_create(struct target *target, struct rtos_type *ostype)
 	return ret;
 }
 
-int rtos_create(Jim_GetOptInfo *goi, struct target *target)
+int rtos_create(struct jim_getopt_info *goi, struct target *target)
 {
 	int x;
 	const char *cp;
-	struct Jim_Obj *res;
+	Jim_Obj *res;
 	int e;
 
 	if (!goi->isconfigure && goi->argc != 0) {
@@ -115,11 +125,14 @@ int rtos_create(Jim_GetOptInfo *goi, struct target *target)
 
 	os_free(target);
 
-	e = Jim_GetOpt_String(goi, &cp, NULL);
+	e = jim_getopt_string(goi, &cp, NULL);
 	if (e != JIM_OK)
 		return e;
 
-	if (0 == strcmp(cp, "auto")) {
+	if (strcmp(cp, "none") == 0)
+		return JIM_OK;
+
+	if (strcmp(cp, "auto") == 0) {
 		/* Auto detect tries to look up all symbols for each RTOS,
 		 * and runs the RTOS driver's _detect() function when GDB
 		 * finds all symbols for any RTOS. See rtos_qsymbol(). */
@@ -131,56 +144,58 @@ int rtos_create(Jim_GetOptInfo *goi, struct target *target)
 	}
 
 	for (x = 0; rtos_types[x]; x++)
-		if (0 == strcmp(cp, rtos_types[x]->name))
+		if (strcmp(cp, rtos_types[x]->name) == 0)
 			return os_alloc_create(target, rtos_types[x]);
 
 	Jim_SetResultFormatted(goi->interp, "Unknown RTOS type %s, try one of: ", cp);
 	res = Jim_GetResult(goi->interp);
 	for (x = 0; rtos_types[x]; x++)
 		Jim_AppendStrings(goi->interp, res, rtos_types[x]->name, ", ", NULL);
-	Jim_AppendStrings(goi->interp, res, " or auto", NULL);
+	Jim_AppendStrings(goi->interp, res, ", auto or none", NULL);
 
 	return JIM_ERR;
 }
 
+void rtos_destroy(struct target *target)
+{
+	os_free(target);
+}
+
 int gdb_thread_packet(struct connection *connection, char const *packet, int packet_size)
 {
 	struct target *target = get_target_from_connection(connection);
-	if (target->rtos == NULL)
+	if (!target->rtos)
 		return rtos_thread_packet(connection, packet, packet_size);	/* thread not
 										 *found*/
 	return target->rtos->gdb_thread_packet(connection, packet, packet_size);
 }
 
-static symbol_table_elem_t *next_symbol(struct rtos *os, char *cur_symbol, uint64_t cur_addr)
+static struct symbol_table_elem *find_symbol(const struct rtos *os, const char *symbol)
 {
-	symbol_table_elem_t *s;
+	struct symbol_table_elem *s;
 
+	for (s = os->symbols; s->symbol_name; s++)
+		if (!strcmp(s->symbol_name, symbol))
+			return s;
+
+	return NULL;
+}
+
+static struct symbol_table_elem *next_symbol(struct rtos *os, char *cur_symbol, uint64_t cur_addr)
+{
 	if (!os->symbols)
 		os->type->get_symbol_list_to_lookup(&os->symbols);
 
 	if (!cur_symbol[0])
 		return &os->symbols[0];
 
-	for (s = os->symbols; s->symbol_name; s++)
-		if (!strcmp(s->symbol_name, cur_symbol)) {
-			s->address = cur_addr;
-			s++;
-			return s;
-		}
+	struct symbol_table_elem *s = find_symbol(os, cur_symbol);
+	if (!s)
+		return NULL;
 
-	return NULL;
-}
-
-/* searches for 'symbol' in the lookup table for 'os' and returns TRUE,
- * if 'symbol' is not declared optional */
-static bool is_symbol_mandatory(const struct rtos *os, const char *symbol)
-{
-	for (symbol_table_elem_t *s = os->symbols; s->symbol_name; ++s) {
-		if (!strcmp(s->symbol_name, symbol))
-			return !s->optional;
-	}
-	return false;
+	s->address = cur_addr;
+	s++;
+	return s;
 }
 
 /* rtos_qsymbol() processes and replies to all qSymbol packets from GDB.
@@ -200,6 +215,12 @@ static bool is_symbol_mandatory(const struct rtos *os, const char *symbol)
  * specified explicitly, then no further symbol lookup is done. When
  * auto-detecting, the RTOS driver _detect() function must return success.
  *
+ * The symbol is tried twice to handle the -flto case with gcc.  The first
+ * attempt uses the symbol as-is, and the second attempt tries the symbol
+ * with ".lto_priv.0" appended to it.  We only consider the first static
+ * symbol here from the -flto case.  (Each subsequent static symbol with
+ * the same name is exported as .lto_priv.1, .lto_priv.2, etc.)
+ *
  * rtos_qsymbol() returns 1 if an RTOS has been detected, or 0 otherwise.
  */
 int rtos_qsymbol(struct connection *connection, char const *packet, int packet_size)
@@ -207,8 +228,8 @@ int rtos_qsymbol(struct connection *connection, char const *packet, int packet_s
 	int rtos_detected = 0;
 	uint64_t addr = 0;
 	size_t reply_len;
-	char reply[GDB_BUFFER_SIZE], cur_sym[GDB_BUFFER_SIZE / 2] = "";
-	symbol_table_elem_t *next_sym = NULL;
+	char reply[GDB_BUFFER_SIZE + 1], cur_sym[GDB_BUFFER_SIZE / 2 + 1] = ""; /* Extra byte for null-termination */
+	struct symbol_table_elem *next_sym = NULL;
 	struct target *target = get_target_from_connection(connection);
 	struct rtos *os = target->rtos;
 
@@ -221,26 +242,62 @@ int rtos_qsymbol(struct connection *connection, char const *packet, int packet_s
 	size_t len = unhexify((uint8_t *)cur_sym, strchr(packet + 8, ':') + 1, strlen(strchr(packet + 8, ':') + 1));
 	cur_sym[len] = 0;
 
+	const char no_suffix[] = "";
+	const char lto_suffix[] = ".lto_priv.0";
+	const size_t lto_suffix_len = strlen(lto_suffix);
+
+	const char *cur_suffix;
+	const char *next_suffix;
+
+	/* Detect what suffix was used during the previous symbol lookup attempt, and
+	 * speculatively determine the next suffix (only used for the unknown address case) */
+	if (len > lto_suffix_len && !strcmp(cur_sym + len - lto_suffix_len, lto_suffix)) {
+		/* Trim the suffix from cur_sym for comparison purposes below */
+		cur_sym[len - lto_suffix_len] = '\0';
+		cur_suffix = lto_suffix;
+		next_suffix = NULL;
+	} else {
+		cur_suffix = no_suffix;
+		next_suffix = lto_suffix;
+	}
+
 	if ((strcmp(packet, "qSymbol::") != 0) &&               /* GDB is not offering symbol lookup for the first time */
-	    (!sscanf(packet, "qSymbol:%" SCNx64 ":", &addr)) && /* GDB did not find an address for a symbol */
-	    is_symbol_mandatory(os, cur_sym)) {					/* the symbol is mandatory for this RTOS */
+	    (!sscanf(packet, "qSymbol:%" SCNx64 ":", &addr))) { /* GDB did not find an address for a symbol */
 
 		/* GDB could not find an address for the previous symbol */
-		if (!target->rtos_auto_detect) {
-			LOG_WARNING("RTOS %s not detected. (GDB could not find symbol \'%s\')", os->type->name, cur_sym);
-			goto done;
-		} else {
-			/* Autodetecting RTOS - try next RTOS */
-			if (!rtos_try_next(target)) {
-				LOG_WARNING("No RTOS could be auto-detected!");
-				goto done;
-			}
+		struct symbol_table_elem *sym = find_symbol(os, cur_sym);
 
-			/* Next RTOS selected - invalidate current symbol */
-			cur_sym[0] = '\x00';
+		if (next_suffix) {
+			next_sym = sym;
+		} else if (sym && !sym->optional) {	/* the symbol is mandatory for this RTOS */
+			if (!target->rtos_auto_detect) {
+				LOG_WARNING("RTOS %s not detected. (GDB could not find symbol \'%s\')", os->type->name, cur_sym);
+				goto done;
+			} else {
+				/* Autodetecting RTOS - try next RTOS */
+				if (!rtos_try_next(target)) {
+					LOG_WARNING("No RTOS could be auto-detected!");
+					goto done;
+				}
+
+				/* Next RTOS selected - invalidate current symbol */
+				cur_sym[0] = '\x00';
+			}
 		}
 	}
-	next_sym = next_symbol(os, cur_sym, addr);
+
+	LOG_DEBUG("RTOS: Address of symbol '%s%s' is 0x%" PRIx64, cur_sym, cur_suffix, addr);
+
+	if (!next_sym) {
+		next_sym = next_symbol(os, cur_sym, addr);
+		next_suffix = no_suffix;
+	}
+
+	/* Should never happen unless the debugger misbehaves */
+	if (!next_sym) {
+		LOG_WARNING("RTOS: Debugger sent us qSymbol with '%s%s' that we did not ask for", cur_sym, cur_suffix);
+		goto done;
+	}
 
 	if (!next_sym->symbol_name) {
 		/* No more symbols need looking up */
@@ -260,15 +317,26 @@ int rtos_qsymbol(struct connection *connection, char const *packet, int packet_s
 		}
 	}
 
-	if (8 + (strlen(next_sym->symbol_name) * 2) + 1 > sizeof(reply)) {
-		LOG_ERROR("ERROR: RTOS symbol '%s' name is too long for GDB!", next_sym->symbol_name);
+	assert(next_suffix);
+
+	reply_len = 8;                                   /* snprintf(..., "qSymbol:") */
+	reply_len += 2 * strlen(next_sym->symbol_name);  /* hexify(..., next_sym->symbol_name, ...) */
+	reply_len += 2 * strlen(next_suffix);            /* hexify(..., next_suffix, ...) */
+	reply_len += 1;                                  /* Terminating NUL */
+	if (reply_len > sizeof(reply)) {
+		LOG_ERROR("ERROR: RTOS symbol '%s%s' name is too long for GDB!", next_sym->symbol_name, next_suffix);
 		goto done;
 	}
 
+	LOG_DEBUG("RTOS: Requesting symbol lookup of '%s%s' from the debugger", next_sym->symbol_name, next_suffix);
+
 	reply_len = snprintf(reply, sizeof(reply), "qSymbol:");
 	reply_len += hexify(reply + reply_len,
 		(const uint8_t *)next_sym->symbol_name, strlen(next_sym->symbol_name),
 		sizeof(reply) - reply_len);
+	reply_len += hexify(reply + reply_len,
+		(const uint8_t *)next_suffix, strlen(next_suffix),
+		sizeof(reply) - reply_len);
 
 done:
 	gdb_put_packet(connection, reply, reply_len);
@@ -280,13 +348,13 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 	struct target *target = get_target_from_connection(connection);
 
 	if (strncmp(packet, "qThreadExtraInfo,", 17) == 0) {
-		if ((target->rtos != NULL) && (target->rtos->thread_details != NULL) &&
+		if ((target->rtos) && (target->rtos->thread_details) &&
 				(target->rtos->thread_count != 0)) {
 			threadid_t threadid = 0;
 			int found = -1;
 			sscanf(packet, "qThreadExtraInfo,%" SCNx64, &threadid);
 
-			if ((target->rtos != NULL) && (target->rtos->thread_details != NULL)) {
+			if ((target->rtos) && (target->rtos->thread_details)) {
 				int thread_num;
 				for (thread_num = 0; thread_num < target->rtos->thread_count; thread_num++) {
 					if (target->rtos->thread_details[thread_num].threadid == threadid) {
@@ -303,17 +371,17 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 			struct thread_detail *detail = &target->rtos->thread_details[found];
 
 			int str_size = 0;
-			if (detail->thread_name_str != NULL)
+			if (detail->thread_name_str)
 				str_size += strlen(detail->thread_name_str);
-			if (detail->extra_info_str != NULL)
+			if (detail->extra_info_str)
 				str_size += strlen(detail->extra_info_str);
 
 			char *tmp_str = calloc(str_size + 9, sizeof(char));
 			char *tmp_str_ptr = tmp_str;
 
-			if (detail->thread_name_str != NULL)
+			if (detail->thread_name_str)
 				tmp_str_ptr += sprintf(tmp_str_ptr, "Name: %s", detail->thread_name_str);
-			if (detail->extra_info_str != NULL) {
+			if (detail->extra_info_str) {
 				if (tmp_str_ptr != tmp_str)
 					tmp_str_ptr += sprintf(tmp_str_ptr, ", ");
 				tmp_str_ptr += sprintf(tmp_str_ptr, "%s", detail->extra_info_str);
@@ -336,14 +404,16 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 		return ERROR_OK;
 	} else if (strncmp(packet, "qSymbol", 7) == 0) {
 		if (rtos_qsymbol(connection, packet, packet_size) == 1) {
-			target->rtos_auto_detect = false;
-			target->rtos->type->create(target);
+			if (target->rtos_auto_detect == true) {
+				target->rtos_auto_detect = false;
+				target->rtos->type->create(target);
+			}
 			target->rtos->type->update_threads(target->rtos);
 		}
 		return ERROR_OK;
 	} else if (strncmp(packet, "qfThreadInfo", 12) == 0) {
 		int i;
-		if (target->rtos != NULL) {
+		if (target->rtos) {
 			if (target->rtos->thread_count == 0) {
 				gdb_put_packet(connection, "l", 1);
 			} else {
@@ -376,7 +446,7 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 		 * otherwise it gets incorrectly handled */
 		return GDB_THREAD_PACKET_NOT_CONSUMED;
 	} else if (strncmp(packet, "qC", 2) == 0) {
-		if (target->rtos != NULL) {
+		if (target->rtos) {
 			char buffer[19];
 			int size;
 			size = snprintf(buffer, 19, "QC%016" PRIx64, target->rtos->current_thread);
@@ -388,7 +458,7 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 		threadid_t threadid;
 		int found = -1;
 		sscanf(packet, "T%" SCNx64, &threadid);
-		if ((target->rtos != NULL) && (target->rtos->thread_details != NULL)) {
+		if ((target->rtos) && (target->rtos->thread_details)) {
 			int thread_num;
 			for (thread_num = 0; thread_num < target->rtos->thread_count; thread_num++) {
 				if (target->rtos->thread_details[thread_num].threadid == threadid) {
@@ -404,7 +474,7 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 		return ERROR_OK;
 	} else if (packet[0] == 'H') {	/* Set current thread ( 'c' for step and continue, 'g' for
 					 * all other operations ) */
-		if ((packet[1] == 'g') && (target->rtos != NULL)) {
+		if ((packet[1] == 'g') && (target->rtos)) {
 			threadid_t threadid;
 			sscanf(packet, "Hg%16" SCNx64, &threadid);
 			LOG_DEBUG("RTOS: GDB requested to set current thread to 0x%" PRIx64, threadid);
@@ -421,15 +491,92 @@ int rtos_thread_packet(struct connection *connection, char const *packet, int pa
 	return GDB_THREAD_PACKET_NOT_CONSUMED;
 }
 
+static int rtos_put_gdb_reg_list(struct connection *connection,
+		struct rtos_reg *reg_list, int num_regs)
+{
+	size_t num_bytes = 1; /* NUL */
+	for (int i = 0; i < num_regs; ++i)
+		num_bytes += DIV_ROUND_UP(reg_list[i].size, 8) * 2;
+
+	char *hex = malloc(num_bytes);
+	char *hex_p = hex;
+
+	for (int i = 0; i < num_regs; ++i) {
+		size_t count = DIV_ROUND_UP(reg_list[i].size, 8);
+		size_t n = hexify(hex_p, reg_list[i].value, count, num_bytes);
+		hex_p += n;
+		num_bytes -= n;
+	}
+
+	gdb_put_packet(connection, hex, strlen(hex));
+	free(hex);
+
+	return ERROR_OK;
+}
+
+/** Look through all registers to find this register. */
+int rtos_get_gdb_reg(struct connection *connection, int reg_num)
+{
+	struct target *target = get_target_from_connection(connection);
+	int64_t current_threadid = target->rtos->current_threadid;
+	if ((target->rtos) && (current_threadid != -1) &&
+			(current_threadid != 0) &&
+			((current_threadid != target->rtos->current_thread) ||
+			(target->smp))) {	/* in smp several current thread are possible */
+		struct rtos_reg *reg_list;
+		int num_regs;
+
+		LOG_DEBUG("getting register %d for thread 0x%" PRIx64
+				  ", target->rtos->current_thread=0x%" PRIx64,
+										reg_num,
+										current_threadid,
+										target->rtos->current_thread);
+
+		int retval;
+		if (target->rtos->type->get_thread_reg) {
+			reg_list = calloc(1, sizeof(*reg_list));
+			num_regs = 1;
+			retval = target->rtos->type->get_thread_reg(target->rtos,
+					current_threadid, reg_num, &reg_list[0]);
+			if (retval != ERROR_OK) {
+				LOG_ERROR("RTOS: failed to get register %d", reg_num);
+				return retval;
+			}
+		} else {
+			retval = target->rtos->type->get_thread_reg_list(target->rtos,
+					current_threadid,
+					&reg_list,
+					&num_regs);
+			if (retval != ERROR_OK) {
+				LOG_ERROR("RTOS: failed to get register list");
+				return retval;
+			}
+		}
+
+		for (int i = 0; i < num_regs; ++i) {
+			if (reg_list[i].number == (uint32_t)reg_num) {
+				rtos_put_gdb_reg_list(connection, reg_list + i, 1);
+				free(reg_list);
+				return ERROR_OK;
+			}
+		}
+
+		free(reg_list);
+	}
+	return ERROR_FAIL;
+}
+
+/** Return a list of general registers. */
 int rtos_get_gdb_reg_list(struct connection *connection)
 {
 	struct target *target = get_target_from_connection(connection);
 	int64_t current_threadid = target->rtos->current_threadid;
-	if ((target->rtos != NULL) && (current_threadid != -1) &&
+	if ((target->rtos) && (current_threadid != -1) &&
 			(current_threadid != 0) &&
 			((current_threadid != target->rtos->current_thread) ||
 			(target->smp))) {	/* in smp several current thread are possible */
-		char *hex_reg_list;
+		struct rtos_reg *reg_list;
+		int num_regs;
 
 		LOG_DEBUG("RTOS: getting register list for thread 0x%" PRIx64
 				  ", target->rtos->current_thread=0x%" PRIx64 "\r\n",
@@ -438,17 +585,31 @@ int rtos_get_gdb_reg_list(struct connection *connection)
 
 		int retval = target->rtos->type->get_thread_reg_list(target->rtos,
 				current_threadid,
-				&hex_reg_list);
+				&reg_list,
+				&num_regs);
 		if (retval != ERROR_OK) {
 			LOG_ERROR("RTOS: failed to get register list");
 			return retval;
 		}
 
-		if (hex_reg_list != NULL) {
-			gdb_put_packet(connection, hex_reg_list, strlen(hex_reg_list));
-			free(hex_reg_list);
-			return ERROR_OK;
-		}
+		rtos_put_gdb_reg_list(connection, reg_list, num_regs);
+		free(reg_list);
+
+		return ERROR_OK;
+	}
+	return ERROR_FAIL;
+}
+
+int rtos_set_reg(struct connection *connection, int reg_num,
+		uint8_t *reg_value)
+{
+	struct target *target = get_target_from_connection(connection);
+	int64_t current_threadid = target->rtos->current_threadid;
+	if ((target->rtos) &&
+			(target->rtos->type->set_reg) &&
+			(current_threadid != -1) &&
+			(current_threadid != 0)) {
+		return target->rtos->type->set_reg(target->rtos, reg_num, reg_value);
 	}
 	return ERROR_FAIL;
 }
@@ -456,12 +617,9 @@ int rtos_get_gdb_reg_list(struct connection *connection)
 int rtos_generic_stack_read(struct target *target,
 	const struct rtos_register_stacking *stacking,
 	int64_t stack_ptr,
-	char **hex_reg_list)
+	struct rtos_reg **reg_list,
+	int *num_regs)
 {
-	int list_size = 0;
-	char *tmp_str_ptr;
-	int64_t new_stack_ptr;
-	int i;
 	int retval;
 
 	if (stack_ptr == 0) {
@@ -488,36 +646,36 @@ int rtos_generic_stack_read(struct target *target,
 			LOG_OUTPUT("%02X", stack_data[i]);
 		LOG_OUTPUT("\r\n");
 #endif
-	for (i = 0; i < stacking->num_output_registers; i++)
-		list_size += stacking->register_offsets[i].width_bits/8;
-	*hex_reg_list = malloc(list_size*2 + 1);
-	tmp_str_ptr = *hex_reg_list;
-	if (stacking->calculate_process_stack != NULL) {
+
+	target_addr_t new_stack_ptr;
+	if (stacking->calculate_process_stack) {
 		new_stack_ptr = stacking->calculate_process_stack(target,
 				stack_data, stacking, stack_ptr);
 	} else {
 		new_stack_ptr = stack_ptr - stacking->stack_growth_direction *
 			stacking->stack_registers_size;
 	}
-	for (i = 0; i < stacking->num_output_registers; i++) {
-		int j;
-		for (j = 0; j < stacking->register_offsets[i].width_bits/8; j++) {
-			if (stacking->register_offsets[i].offset == -1)
-				tmp_str_ptr += sprintf(tmp_str_ptr, "%02x", 0);
-			else if (stacking->register_offsets[i].offset == -2)
-				tmp_str_ptr += sprintf(tmp_str_ptr, "%02x",
-						((uint8_t *)&new_stack_ptr)[j]);
-			else
-				tmp_str_ptr += sprintf(tmp_str_ptr, "%02x",
-						stack_data[stacking->register_offsets[i].offset + j]);
-		}
+
+	*reg_list = calloc(stacking->num_output_registers, sizeof(struct rtos_reg));
+	*num_regs = stacking->num_output_registers;
+
+	for (int i = 0; i < stacking->num_output_registers; ++i) {
+		(*reg_list)[i].number = stacking->register_offsets[i].number;
+		(*reg_list)[i].size = stacking->register_offsets[i].width_bits;
+
+		int offset = stacking->register_offsets[i].offset;
+		if (offset == -2)
+			buf_cpy(&new_stack_ptr, (*reg_list)[i].value, (*reg_list)[i].size);
+		else if (offset != -1)
+			buf_cpy(stack_data + offset, (*reg_list)[i].value, (*reg_list)[i].size);
 	}
+
 	free(stack_data);
 /*	LOG_OUTPUT("Output register string: %s\r\n", *hex_reg_list); */
 	return ERROR_OK;
 }
 
-int rtos_try_next(struct target *target)
+static int rtos_try_next(struct target *target)
 {
 	struct rtos *os = target->rtos;
 	struct rtos_type **type = rtos_types;
@@ -532,17 +690,16 @@ int rtos_try_next(struct target *target)
 		return 0;
 
 	os->type = *type;
-	if (os->symbols) {
-		free(os->symbols);
-		os->symbols = NULL;
-	}
+
+	free(os->symbols);
+	os->symbols = NULL;
 
 	return 1;
 }
 
 int rtos_update_threads(struct target *target)
 {
-	if ((target->rtos != NULL) && (target->rtos->type != NULL))
+	if ((target->rtos) && (target->rtos->type))
 		target->rtos->type->update_threads(target->rtos);
 	return ERROR_OK;
 }
@@ -564,3 +721,19 @@ void rtos_free_threadlist(struct rtos *rtos)
 		rtos->current_thread = 0;
 	}
 }
+
+int rtos_read_buffer(struct target *target, target_addr_t address,
+		uint32_t size, uint8_t *buffer)
+{
+	if (target->rtos->type->read_buffer)
+		return target->rtos->type->read_buffer(target->rtos, address, size, buffer);
+	return ERROR_NOT_IMPLEMENTED;
+}
+
+int rtos_write_buffer(struct target *target, target_addr_t address,
+		uint32_t size, const uint8_t *buffer)
+{
+	if (target->rtos->type->write_buffer)
+		return target->rtos->type->write_buffer(target->rtos, address, size, buffer);
+	return ERROR_NOT_IMPLEMENTED;
+}
