@@ -1,28 +1,17 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *    Copyright (C) 2009 by Simon Qian                                     *
  *    SimonQian@SimonQian.com                                              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 /* The specification for SVF is available here:
  * http://www.asset-intertech.com/support/svf.pdf
- * Below, this document is refered to as the "SVF spec".
+ * Below, this document is referred to as the "SVF spec".
  *
  * The specification for XSVF is available here:
  * http://www.xilinx.com/support/documentation/application_notes/xapp503.pdf
- * Below, this document is refered to as the "XSVF spec".
+ * Below, this document is referred to as the "XSVF spec".
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +20,7 @@
 
 #include <jtag/jtag.h>
 #include "svf.h"
+#include "helper/system.h"
 #include <helper/time_support.h>
 
 /* SVF command */
@@ -226,12 +216,12 @@ static int svf_getline(char **lineptr, size_t *n, FILE *stream);
 
 #define SVF_MAX_BUFFER_SIZE_TO_COMMIT   (1024 * 1024)
 static uint8_t *svf_tdi_buffer, *svf_tdo_buffer, *svf_mask_buffer;
-static int svf_buffer_index, svf_buffer_size ;
+static int svf_buffer_index, svf_buffer_size;
 static int svf_quiet;
 static int svf_nil;
 static int svf_ignore_error;
 
-/* Targetting particular tap */
+/* Targeting particular tap */
 static int svf_tap_is_specified;
 static int svf_set_padding(struct svf_xxr_para *para, int len, unsigned char tdi);
 
@@ -246,7 +236,7 @@ static int svf_last_printed_percentage = -1;
  * DEBUG, INFO, ERROR, USER
  */
 #define SVF_BUF_LOG(_lvl, _buf, _nbits, _desc)							\
-	svf_hexbuf_print(LOG_LVL_##_lvl ,  __FILE__, __LINE__, __func__, _buf, _nbits, _desc)
+	svf_hexbuf_print(LOG_LVL_##_lvl,  __FILE__, __LINE__, __func__, _buf, _nbits, _desc)
 
 static void svf_hexbuf_print(int dbg_lvl, const char *file, unsigned line,
 							 const char *function, const uint8_t *buf,
@@ -301,23 +291,18 @@ static int svf_realloc_buffers(size_t len)
 
 static void svf_free_xxd_para(struct svf_xxr_para *para)
 {
-	if (NULL != para) {
-		if (para->tdi != NULL) {
-			free(para->tdi);
-			para->tdi = NULL;
-		}
-		if (para->tdo != NULL) {
-			free(para->tdo);
-			para->tdo = NULL;
-		}
-		if (para->mask != NULL) {
-			free(para->mask);
-			para->mask = NULL;
-		}
-		if (para->smask != NULL) {
-			free(para->smask);
-			para->smask = NULL;
-		}
+	if (para) {
+		free(para->tdi);
+		para->tdi = NULL;
+
+		free(para->tdo);
+		para->tdo = NULL;
+
+		free(para->mask);
+		para->mask = NULL;
+
+		free(para->smask);
+		para->smask = NULL;
 	}
 }
 
@@ -382,7 +367,7 @@ COMMAND_HANDLER(handle_svf_command)
 		if (strcmp(CMD_ARGV[i], "-tap") == 0) {
 			tap = jtag_tap_by_string(CMD_ARGV[i+1]);
 			if (!tap) {
-				command_print(CMD_CTX, "Tap: %s unknown", CMD_ARGV[i+1]);
+				command_print(CMD, "Tap: %s unknown", CMD_ARGV[i+1]);
 				return ERROR_FAIL;
 			}
 			i++;
@@ -399,9 +384,9 @@ COMMAND_HANDLER(handle_svf_command)
 			svf_ignore_error = 1;
 		else {
 			svf_fd = fopen(CMD_ARGV[i], "r");
-			if (svf_fd == NULL) {
+			if (!svf_fd) {
 				int err = errno;
-				command_print(CMD_CTX, "open(\"%s\"): %s", CMD_ARGV[i], strerror(err));
+				command_print(CMD, "open(\"%s\"): %s", CMD_ARGV[i], strerror(err));
 				/* no need to free anything now */
 				return ERROR_COMMAND_SYNTAX_ERROR;
 			} else
@@ -409,7 +394,7 @@ COMMAND_HANDLER(handle_svf_command)
 		}
 	}
 
-	if (svf_fd == NULL)
+	if (!svf_fd)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	/* get time */
@@ -421,7 +406,7 @@ COMMAND_HANDLER(handle_svf_command)
 
 	svf_check_tdo_para_index = 0;
 	svf_check_tdo_para = malloc(sizeof(struct svf_check_tdo_para) * SVF_CHECK_TDO_PARA_SIZE);
-	if (NULL == svf_check_tdo_para) {
+	if (!svf_check_tdo_para) {
 		LOG_ERROR("not enough memory");
 		ret = ERROR_FAIL;
 		goto free_all;
@@ -464,25 +449,25 @@ COMMAND_HANDLER(handle_svf_command)
 		}
 
 		/* HDR %d TDI (0) */
-		if (ERROR_OK != svf_set_padding(&svf_para.hdr_para, header_dr_len, 0)) {
+		if (svf_set_padding(&svf_para.hdr_para, header_dr_len, 0) != ERROR_OK) {
 			LOG_ERROR("failed to set data header");
 			return ERROR_FAIL;
 		}
 
 		/* HIR %d TDI (0xFF) */
-		if (ERROR_OK != svf_set_padding(&svf_para.hir_para, header_ir_len, 0xFF)) {
+		if (svf_set_padding(&svf_para.hir_para, header_ir_len, 0xFF) != ERROR_OK) {
 			LOG_ERROR("failed to set instruction header");
 			return ERROR_FAIL;
 		}
 
 		/* TDR %d TDI (0) */
-		if (ERROR_OK != svf_set_padding(&svf_para.tdr_para, trailer_dr_len, 0)) {
+		if (svf_set_padding(&svf_para.tdr_para, trailer_dr_len, 0) != ERROR_OK) {
 			LOG_ERROR("failed to set data trailer");
 			return ERROR_FAIL;
 		}
 
 		/* TIR %d TDI (0xFF) */
-		if (ERROR_OK != svf_set_padding(&svf_para.tir_para, trailer_ir_len, 0xFF)) {
+		if (svf_set_padding(&svf_para.tir_para, trailer_ir_len, 0xFF) != ERROR_OK) {
 			LOG_ERROR("failed to set instruction trailer");
 			return ERROR_FAIL;
 		}
@@ -496,7 +481,7 @@ COMMAND_HANDLER(handle_svf_command)
 		}
 		rewind(svf_fd);
 	}
-	while (ERROR_OK == svf_read_command_from_file(svf_fd)) {
+	while (svf_read_command_from_file(svf_fd) == ERROR_OK) {
 		/* Log Output */
 		if (svf_quiet) {
 			if (svf_progress_enabled) {
@@ -514,7 +499,7 @@ COMMAND_HANDLER(handle_svf_command)
 				LOG_USER_N("%s", svf_read_line);
 		}
 		/* Run Command */
-		if (ERROR_OK != svf_run_command(CMD_CTX, svf_command_buffer)) {
+		if (svf_run_command(CMD_CTX, svf_command_buffer) != ERROR_OK) {
 			LOG_ERROR("fail to run command at line %d", svf_line_number);
 			ret = ERROR_FAIL;
 			break;
@@ -522,9 +507,9 @@ COMMAND_HANDLER(handle_svf_command)
 		command_num++;
 	}
 
-	if ((!svf_nil) && (ERROR_OK != jtag_execute_queue()))
+	if ((!svf_nil) && (jtag_execute_queue() != ERROR_OK))
 		ret = ERROR_FAIL;
-	else if (ERROR_OK != svf_check_tdo())
+	else if (svf_check_tdo() != ERROR_OK)
 		ret = ERROR_FAIL;
 
 	/* print time */
@@ -534,7 +519,7 @@ COMMAND_HANDLER(handle_svf_command)
 	time_measure_m = time_measure_s / 60;
 	time_measure_s %= 60;
 	if (time_measure_ms < 1000)
-		command_print(CMD_CTX,
+		command_print(CMD,
 			"\r\nTime used: %dm%ds%" PRId64 "ms ",
 			time_measure_m,
 			time_measure_s,
@@ -546,28 +531,23 @@ free_all:
 	svf_fd = 0;
 
 	/* free buffers */
-	if (svf_command_buffer) {
-		free(svf_command_buffer);
-		svf_command_buffer = NULL;
-		svf_command_buffer_size = 0;
-	}
-	if (svf_check_tdo_para) {
-		free(svf_check_tdo_para);
-		svf_check_tdo_para = NULL;
-		svf_check_tdo_para_index = 0;
-	}
-	if (svf_tdi_buffer) {
-		free(svf_tdi_buffer);
-		svf_tdi_buffer = NULL;
-	}
-	if (svf_tdo_buffer) {
-		free(svf_tdo_buffer);
-		svf_tdo_buffer = NULL;
-	}
-	if (svf_mask_buffer) {
-		free(svf_mask_buffer);
-		svf_mask_buffer = NULL;
-	}
+	free(svf_command_buffer);
+	svf_command_buffer = NULL;
+	svf_command_buffer_size = 0;
+
+	free(svf_check_tdo_para);
+	svf_check_tdo_para = NULL;
+	svf_check_tdo_para_index = 0;
+
+	free(svf_tdi_buffer);
+	svf_tdi_buffer = NULL;
+
+	free(svf_tdo_buffer);
+	svf_tdo_buffer = NULL;
+
+	free(svf_mask_buffer);
+	svf_mask_buffer = NULL;
+
 	svf_buffer_index = 0;
 	svf_buffer_size = 0;
 
@@ -578,14 +558,14 @@ free_all:
 	svf_free_xxd_para(&svf_para.sdr_para);
 	svf_free_xxd_para(&svf_para.sir_para);
 
-	if (ERROR_OK == ret)
-		command_print(CMD_CTX,
+	if (ret == ERROR_OK)
+		command_print(CMD,
 			      "svf file programmed %s for %d commands with %d errors",
 			      (svf_ignore_error > 1) ? "unsuccessfully" : "successfully",
 			      command_num,
 			      (svf_ignore_error > 1) ? (svf_ignore_error - 1) : 0);
 	else
-		command_print(CMD_CTX, "svf file programmed failed");
+		command_print(CMD, "svf file programmed failed");
 
 	svf_ignore_error = 0;
 	return ret;
@@ -596,7 +576,7 @@ static int svf_getline(char **lineptr, size_t *n, FILE *stream)
 #define MIN_CHUNK 16	/* Buffer is increased by this size each time as required */
 	size_t i = 0;
 
-	if (*lineptr == NULL) {
+	if (!*lineptr) {
 		*n = MIN_CHUNK;
 		*lineptr = malloc(*n);
 		if (!*lineptr)
@@ -661,11 +641,13 @@ static int svf_read_command_from_file(FILE *fd)
 				if (svf_getline(&svf_read_line, &svf_read_line_size, svf_fd) <= 0)
 					return ERROR_FAIL;
 				i = -1;
+				/* fallthrough */
 			case '\r':
 				slash = 0;
 				/* Don't save '\r' and '\n' if no data is parsed */
 				if (!cmd_pos)
 					break;
+				/* fallthrough */
 			default:
 				/* The parsing code currently expects a space
 				 * before parentheses -- "TDI (123)".  Also a
@@ -682,7 +664,7 @@ static int svf_read_command_from_file(FILE *fd)
 				if (cmd_pos + 3 > svf_command_buffer_size) {
 					svf_command_buffer = realloc(svf_command_buffer, cmd_pos + 3);
 					svf_command_buffer_size = cmd_pos + 3;
-					if (svf_command_buffer == NULL) {
+					if (!svf_command_buffer) {
 						LOG_ERROR("not enough memory");
 						return ERROR_FAIL;
 					}
@@ -739,6 +721,9 @@ parse_char:
 		pos++;
 	}
 
+	if (num == 0)
+		return ERROR_FAIL;
+
 	*num_of_argu = num;
 
 	return ERROR_OK;
@@ -746,8 +731,8 @@ parse_char:
 
 bool svf_tap_state_is_stable(tap_state_t state)
 {
-	return (TAP_RESET == state) || (TAP_IDLE == state)
-			|| (TAP_DRPAUSE == state) || (TAP_IRPAUSE == state);
+	return (state == TAP_RESET) || (state == TAP_IDLE)
+			|| (state == TAP_DRPAUSE) || (state == TAP_IRPAUSE);
 }
 
 static int svf_find_string_in_array(char *str, char **strs, int num_of_element)
@@ -765,17 +750,13 @@ static int svf_adjust_array_length(uint8_t **arr, int orig_bit_len, int new_bit_
 {
 	int new_byte_len = (new_bit_len + 7) >> 3;
 
-	if ((NULL == *arr) || (((orig_bit_len + 7) >> 3) < ((new_bit_len + 7) >> 3))) {
-		if (*arr != NULL) {
-			free(*arr);
-			*arr = NULL;
-		}
-		*arr = malloc(new_byte_len);
-		if (NULL == *arr) {
+	if ((!*arr) || (((orig_bit_len + 7) >> 3) < ((new_bit_len + 7) >> 3))) {
+		free(*arr);
+		*arr = calloc(1, new_byte_len);
+		if (!*arr) {
 			LOG_ERROR("not enough memory");
 			return ERROR_FAIL;
 		}
-		memset(*arr, 0, new_byte_len);
 	}
 	return ERROR_OK;
 }
@@ -798,7 +779,7 @@ static int svf_copy_hexstring_to_binary(char *str, uint8_t **bin, int orig_bit_l
 	int i, str_len = strlen(str), str_hbyte_len = (bit_len + 3) >> 2;
 	uint8_t ch = 0;
 
-	if (ERROR_OK != svf_adjust_array_length(bin, orig_bit_len, bit_len)) {
+	if (svf_adjust_array_length(bin, orig_bit_len, bit_len) != ERROR_OK) {
 		LOG_ERROR("fail to adjust length of array");
 		return ERROR_FAIL;
 	}
@@ -849,7 +830,7 @@ static int svf_copy_hexstring_to_binary(char *str, uint8_t **bin, int orig_bit_l
 
 	/* check validity: we must have consumed everything */
 	if (str_len > 0 || (ch & ~((2 << ((bit_len - 1) % 4)) - 1)) != 0) {
-		LOG_ERROR("value execeeds length");
+		LOG_ERROR("value exceeds length");
 		return ERROR_FAIL;
 	}
 
@@ -901,9 +882,9 @@ static int svf_add_check_para(uint8_t enabled, int buffer_offset, int bit_len)
 
 static int svf_execute_tap(void)
 {
-	if ((!svf_nil) && (ERROR_OK != jtag_execute_queue()))
+	if ((!svf_nil) && (jtag_execute_queue() != ERROR_OK))
 		return ERROR_FAIL;
-	else if (ERROR_OK != svf_check_tdo())
+	else if (svf_check_tdo() != ERROR_OK)
 		return ERROR_FAIL;
 
 	svf_buffer_index = 0;
@@ -931,7 +912,7 @@ static int svf_run_command(struct command_context *cmd_ctx, char *cmd_str)
 	/* flag padding commands skipped due to -tap command */
 	int padding_command_skipped = 0;
 
-	if (ERROR_OK != svf_parse_cmd_string(cmd_str, strlen(cmd_str), argus, &num_of_argu))
+	if (svf_parse_cmd_string(cmd_str, strlen(cmd_str), argus, &num_of_argu) != ERROR_OK)
 		return ERROR_FAIL;
 
 	/* NOTE: we're a bit loose here, because we ignore case in
@@ -971,7 +952,7 @@ static int svf_run_command(struct command_context *cmd_ctx, char *cmd_str)
 				LOG_ERROR("invalid parameter of %s", argus[0]);
 				return ERROR_FAIL;
 			}
-			if (1 == num_of_argu) {
+			if (num_of_argu == 1) {
 				/* TODO: set jtag speed to full speed */
 				svf_para.frequency = 0;
 			} else {
@@ -979,13 +960,13 @@ static int svf_run_command(struct command_context *cmd_ctx, char *cmd_str)
 					LOG_ERROR("HZ not found in FREQUENCY command");
 					return ERROR_FAIL;
 				}
-				if (ERROR_OK != svf_execute_tap())
+				if (svf_execute_tap() != ERROR_OK)
 					return ERROR_FAIL;
 				svf_para.frequency = atof(argus[1]);
 				/* TODO: set jtag speed to */
 				if (svf_para.frequency > 0) {
 					command_run_linef(cmd_ctx,
-							"adapter_khz %d",
+							"adapter speed %d",
 							(int)svf_para.frequency / 1000);
 					LOG_DEBUG("\tfrequency = %f", svf_para.frequency);
 				}
@@ -997,35 +978,35 @@ static int svf_run_command(struct command_context *cmd_ctx, char *cmd_str)
 				break;
 			}
 			xxr_para_tmp = &svf_para.hdr_para;
-			goto XXR_common;
+			goto xxr_common;
 		case HIR:
 			if (svf_tap_is_specified) {
 				padding_command_skipped = 1;
 				break;
 			}
 			xxr_para_tmp = &svf_para.hir_para;
-			goto XXR_common;
+			goto xxr_common;
 		case TDR:
 			if (svf_tap_is_specified) {
 				padding_command_skipped = 1;
 				break;
 			}
 			xxr_para_tmp = &svf_para.tdr_para;
-			goto XXR_common;
+			goto xxr_common;
 		case TIR:
 			if (svf_tap_is_specified) {
 				padding_command_skipped = 1;
 				break;
 			}
 			xxr_para_tmp = &svf_para.tir_para;
-			goto XXR_common;
+			goto xxr_common;
 		case SDR:
 			xxr_para_tmp = &svf_para.sdr_para;
-			goto XXR_common;
+			goto xxr_common;
 		case SIR:
 			xxr_para_tmp = &svf_para.sir_para;
-			goto XXR_common;
-XXR_common:
+			goto xxr_common;
+xxr_common:
 			/* XXR length [TDI (tdi)] [TDO (tdo)][MASK (mask)] [SMASK (smask)] */
 			if ((num_of_argu > 10) || (num_of_argu % 2)) {
 				LOG_ERROR("invalid parameter of %s", argus[0]);
@@ -1073,7 +1054,7 @@ XXR_common:
 					pbuffer_tmp = &xxr_para_tmp->smask;
 					xxr_para_tmp->data_mask |= XXR_SMASK;
 				} else {
-					LOG_ERROR("unknow parameter: %s", argus[i]);
+					LOG_ERROR("unknown parameter: %s", argus[i]);
 					return ERROR_FAIL;
 				}
 				if (ERROR_OK !=
@@ -1099,7 +1080,7 @@ XXR_common:
 			}
 			/* If TDO is absent, no comparison is needed, set the mask to 0 */
 			if (!(xxr_para_tmp->data_mask & XXR_TDO)) {
-				if (NULL == xxr_para_tmp->tdo) {
+				if (!xxr_para_tmp->tdo) {
 					if (ERROR_OK !=
 					svf_adjust_array_length(&xxr_para_tmp->tdo, i_tmp,
 						xxr_para_tmp->len)) {
@@ -1107,7 +1088,7 @@ XXR_common:
 						return ERROR_FAIL;
 					}
 				}
-				if (NULL == xxr_para_tmp->mask) {
+				if (!xxr_para_tmp->mask) {
 					if (ERROR_OK !=
 					svf_adjust_array_length(&xxr_para_tmp->mask, i_tmp,
 						xxr_para_tmp->len)) {
@@ -1118,7 +1099,7 @@ XXR_common:
 				memset(xxr_para_tmp->mask, 0, (xxr_para_tmp->len + 7) >> 3);
 			}
 			/* do scan if necessary */
-			if (SDR == command) {
+			if (command == SDR) {
 				/* check buffer size first, reallocate if necessary */
 				i = svf_para.hdr_para.len + svf_para.sdr_para.len +
 						svf_para.tdr_para.len;
@@ -1209,7 +1190,7 @@ XXR_common:
 				}
 
 				svf_buffer_index += (i + 7) >> 3;
-			} else if (SIR == command) {
+			} else if (command == SIR) {
 				/* check buffer size first, reallocate if necessary */
 				i = svf_para.hir_para.len + svf_para.sir_para.len +
 						svf_para.tir_para.len;
@@ -1305,13 +1286,12 @@ XXR_common:
 		case PIOMAP:
 			LOG_ERROR("PIO and PIOMAP are not supported");
 			return ERROR_FAIL;
-			break;
 		case RUNTEST:
 			/* RUNTEST [run_state] run_count run_clk [min_time SEC [MAXIMUM max_time
 			 * SEC]] [ENDSTATE end_state] */
 			/* RUNTEST [run_state] min_time SEC [MAXIMUM max_time SEC] [ENDSTATE
 			 * end_state] */
-			if ((num_of_argu < 3) && (num_of_argu > 11)) {
+			if ((num_of_argu < 3) || (num_of_argu > 11)) {
 				LOG_ERROR("invalid parameter of %s", argus[0]);
 				return ERROR_FAIL;
 			}
@@ -1429,7 +1409,7 @@ XXR_common:
 			if (num_of_argu > 2) {
 				/* STATE pathstate1 ... stable_state */
 				path = malloc((num_of_argu - 1) * sizeof(tap_state_t));
-				if (NULL == path) {
+				if (!path) {
 					LOG_ERROR("not enough memory");
 					return ERROR_FAIL;
 				}
@@ -1443,7 +1423,7 @@ XXR_common:
 						return ERROR_FAIL;
 					}
 					/* OpenOCD refuses paths containing TAP_RESET */
-					if (TAP_RESET == path[i]) {
+					if (path[i] == TAP_RESET) {
 						/* FIXME last state MUST be stable! */
 						if (i > 0) {
 							if (!svf_nil)
@@ -1496,7 +1476,7 @@ XXR_common:
 				return ERROR_FAIL;
 			}
 			if (svf_para.trst_mode != TRST_ABSENT) {
-				if (ERROR_OK != svf_execute_tap())
+				if (svf_execute_tap() != ERROR_OK)
 					return ERROR_FAIL;
 				i_tmp = svf_find_string_in_array(argus[1],
 						(char **)svf_trst_mode_name,
@@ -1520,14 +1500,13 @@ XXR_common:
 				svf_para.trst_mode = i_tmp;
 				LOG_DEBUG("\ttrst_mode = %s", svf_trst_mode_name[svf_para.trst_mode]);
 			} else {
-				LOG_ERROR("can not accpet TRST command if trst_mode is ABSENT");
+				LOG_ERROR("can not accept TRST command if trst_mode is ABSENT");
 				return ERROR_FAIL;
 			}
 			break;
 		default:
 			LOG_ERROR("invalid svf command: %s", argus[0]);
 			return ERROR_FAIL;
-			break;
 	}
 
 	if (!svf_quiet) {
@@ -1537,23 +1516,22 @@ XXR_common:
 
 	if (debug_level >= LOG_LVL_DEBUG) {
 		/* for convenient debugging, execute tap if possible */
-		if ((svf_buffer_index > 0) && \
-				(((command != STATE) && (command != RUNTEST)) || \
+		if ((svf_buffer_index > 0) &&
+				(((command != STATE) && (command != RUNTEST)) ||
 						((command == STATE) && (num_of_argu == 2)))) {
-			if (ERROR_OK != svf_execute_tap())
+			if (svf_execute_tap() != ERROR_OK)
 				return ERROR_FAIL;
 
 			/* output debug info */
-			if ((SIR == command) || (SDR == command)) {
+			if ((command == SIR) || (command == SDR))
 				SVF_BUF_LOG(DEBUG, svf_tdi_buffer, svf_check_tdo_para[0].bit_len, "TDO read");
-			}
 		}
 	} else {
 		/* for fast executing, execute tap if necessary */
 		/* half of the buffer is for the next command */
 		if (((svf_buffer_index >= SVF_MAX_BUFFER_SIZE_TO_COMMIT) ||
-				(svf_check_tdo_para_index >= SVF_CHECK_TDO_PARA_SIZE / 2)) && \
-				(((command != STATE) && (command != RUNTEST)) || \
+				(svf_check_tdo_para_index >= SVF_CHECK_TDO_PARA_SIZE / 2)) &&
+				(((command != STATE) && (command != RUNTEST)) ||
 						((command == STATE) && (num_of_argu == 2))))
 			return svf_execute_tap();
 	}
@@ -1567,7 +1545,7 @@ static const struct command_registration svf_command_handlers[] = {
 		.handler = handle_svf_command,
 		.mode = COMMAND_EXEC,
 		.help = "Runs a SVF file.",
-		.usage = "svf [-tap device.tap] <file> [quiet] [nil] [progress] [ignore_error]",
+		.usage = "[-tap device.tap] <file> [quiet] [nil] [progress] [ignore_error]",
 	},
 	COMMAND_REGISTRATION_DONE
 };
