@@ -1,22 +1,11 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2005 by Dominic Rath                                    *
  *   Dominic.Rath@gmx.de                                                   *
  *                                                                         *
  *   Copyright (C) 2009 by Øyvind Harboe                                   *
  *   oyvind.harboe@zylin.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -233,16 +222,6 @@ static void arm720t_pre_restore_context(struct target *target)
 	arm720t_write_cp15(target, 0xee060f10, arm720t->far_reg);
 }
 
-static int arm720t_verify_pointer(struct command_context *cmd_ctx,
-		struct arm720t_common *arm720t)
-{
-	if (arm720t->common_magic != ARM720T_COMMON_MAGIC) {
-		command_print(cmd_ctx, "target is not an ARM720");
-		return ERROR_TARGET_INVALID;
-	}
-	return ERROR_OK;
-}
-
 static int arm720t_arch_state(struct target *target)
 {
 	struct arm720t_common *arm720t = target_to_arm720(target);
@@ -271,7 +250,7 @@ static int arm720_mmu(struct target *target, int *enabled)
 }
 
 static int arm720_virt2phys(struct target *target,
-		uint32_t virtual, uint32_t *physical)
+		target_addr_t virtual, target_addr_t *physical)
 {
 	uint32_t cb;
 	struct arm720t_common *arm720t = target_to_arm720(target);
@@ -286,7 +265,7 @@ static int arm720_virt2phys(struct target *target,
 }
 
 static int arm720t_read_memory(struct target *target,
-		uint32_t address, uint32_t size, uint32_t count, uint8_t *buffer)
+		target_addr_t address, uint32_t size, uint32_t count, uint8_t *buffer)
 {
 	int retval;
 	struct arm720t_common *arm720t = target_to_arm720(target);
@@ -309,7 +288,7 @@ static int arm720t_read_memory(struct target *target,
 }
 
 static int arm720t_read_phys_memory(struct target *target,
-		uint32_t address, uint32_t size, uint32_t count, uint8_t *buffer)
+		target_addr_t address, uint32_t size, uint32_t count, uint8_t *buffer)
 {
 	struct arm720t_common *arm720t = target_to_arm720(target);
 
@@ -317,7 +296,7 @@ static int arm720t_read_phys_memory(struct target *target,
 }
 
 static int arm720t_write_phys_memory(struct target *target,
-		uint32_t address, uint32_t size, uint32_t count, const uint8_t *buffer)
+		target_addr_t address, uint32_t size, uint32_t count, const uint8_t *buffer)
 {
 	struct arm720t_common *arm720t = target_to_arm720(target);
 
@@ -365,12 +344,12 @@ static int arm720t_soft_reset_halt(struct target *target)
 	cpsr &= ~0xff;
 	cpsr |= 0xd3;
 	arm_set_cpsr(arm, cpsr);
-	arm->cpsr->dirty = 1;
+	arm->cpsr->dirty = true;
 
 	/* start fetching from 0x0 */
 	buf_set_u32(arm->pc->value, 0, 32, 0x0);
-	arm->pc->dirty = 1;
-	arm->pc->valid = 1;
+	arm->pc->dirty = true;
+	arm->pc->valid = true;
 
 	retval = arm720t_disable_mmu_caches(target, 1, 1, 1);
 	if (retval != ERROR_OK)
@@ -391,14 +370,19 @@ static int arm720t_init_target(struct command_context *cmd_ctx, struct target *t
 	return arm7tdmi_init_target(cmd_ctx, target);
 }
 
+static void arm720t_deinit_target(struct target *target)
+{
+	arm7tdmi_deinit_target(target);
+}
+
 /* FIXME remove forward decls */
 static int arm720t_mrc(struct target *target, int cpnum,
 		uint32_t op1, uint32_t op2,
-		uint32_t CRn, uint32_t CRm,
+		uint32_t crn, uint32_t crm,
 		uint32_t *value);
 static int arm720t_mcr(struct target *target, int cpnum,
 		uint32_t op1, uint32_t op2,
-		uint32_t CRn, uint32_t CRm,
+		uint32_t crn, uint32_t crm,
 		uint32_t value);
 
 static int arm720t_init_arch_info(struct target *target,
@@ -432,62 +416,13 @@ static int arm720t_target_create(struct target *target, Jim_Interp *interp)
 {
 	struct arm720t_common *arm720t = calloc(1, sizeof(*arm720t));
 
-	arm720t->arm7_9_common.arm.is_armv4 = true;
+	arm720t->arm7_9_common.arm.arch = ARM_ARCH_V4;
 	return arm720t_init_arch_info(target, arm720t, target->tap);
 }
 
-COMMAND_HANDLER(arm720t_handle_cp15_command)
-{
-	int retval;
-	struct target *target = get_current_target(CMD_CTX);
-	struct arm720t_common *arm720t = target_to_arm720(target);
-
-	retval = arm720t_verify_pointer(CMD_CTX, arm720t);
-	if (retval != ERROR_OK)
-		return retval;
-
-	if (target->state != TARGET_HALTED) {
-		command_print(CMD_CTX, "target must be stopped for \"%s\" command", CMD_NAME);
-		return ERROR_OK;
-	}
-
-	/* one or more argument, access a single register (write if second argument is given */
-	if (CMD_ARGC >= 1) {
-		uint32_t opcode;
-		COMMAND_PARSE_NUMBER(u32, CMD_ARGV[0], opcode);
-
-		if (CMD_ARGC == 1) {
-			uint32_t value;
-			retval = arm720t_read_cp15(target, opcode, &value);
-			if (retval != ERROR_OK) {
-				command_print(CMD_CTX, "couldn't access cp15 with opcode 0x%8.8" PRIx32 "", opcode);
-				return ERROR_OK;
-			}
-
-			retval = jtag_execute_queue();
-			if (retval != ERROR_OK)
-				return retval;
-
-			command_print(CMD_CTX, "0x%8.8" PRIx32 ": 0x%8.8" PRIx32 "", opcode, value);
-		} else if (CMD_ARGC == 2) {
-			uint32_t value;
-			COMMAND_PARSE_NUMBER(u32, CMD_ARGV[1], value);
-
-			retval = arm720t_write_cp15(target, opcode, value);
-			if (retval != ERROR_OK) {
-				command_print(CMD_CTX, "couldn't access cp15 with opcode 0x%8.8" PRIx32 "", opcode);
-				return ERROR_OK;
-			}
-			command_print(CMD_CTX, "0x%8.8" PRIx32 ": 0x%8.8" PRIx32 "", opcode, value);
-		}
-	}
-
-	return ERROR_OK;
-}
-
 static int arm720t_mrc(struct target *target, int cpnum,
 		uint32_t op1, uint32_t op2,
-		uint32_t CRn, uint32_t CRm,
+		uint32_t crn, uint32_t crm,
 		uint32_t *value)
 {
 	if (cpnum != 15) {
@@ -497,14 +432,14 @@ static int arm720t_mrc(struct target *target, int cpnum,
 
 	/* read "to" r0 */
 	return arm720t_read_cp15(target,
-			ARMV4_5_MRC(cpnum, op1, 0, CRn, CRm, op2),
+			ARMV4_5_MRC(cpnum, op1, 0, crn, crm, op2),
 			value);
 
 }
 
 static int arm720t_mcr(struct target *target, int cpnum,
 		uint32_t op1, uint32_t op2,
-		uint32_t CRn, uint32_t CRm,
+		uint32_t crn, uint32_t crm,
 		uint32_t value)
 {
 	if (cpnum != 15) {
@@ -514,34 +449,14 @@ static int arm720t_mcr(struct target *target, int cpnum,
 
 	/* write "from" r0 */
 	return arm720t_write_cp15(target,
-			ARMV4_5_MCR(cpnum, op1, 0, CRn, CRm, op2),
+			ARMV4_5_MCR(cpnum, op1, 0, crn, crm, op2),
 			value);
 }
 
-static const struct command_registration arm720t_exec_command_handlers[] = {
-	{
-		.name = "cp15",
-		.handler = arm720t_handle_cp15_command,
-		.mode = COMMAND_EXEC,
-		/* prefer using less error-prone "arm mcr" or "arm mrc" */
-		.help = "display/modify cp15 register using ARM opcode"
-			" (DEPRECATED)",
-		.usage = "instruction [value]",
-	},
-	COMMAND_REGISTRATION_DONE
-};
-
 static const struct command_registration arm720t_command_handlers[] = {
 	{
 		.chain = arm7_9_command_handlers,
 	},
-	{
-		.name = "arm720t",
-		.mode = COMMAND_ANY,
-		.help = "arm720t command group",
-		.usage = "",
-		.chain = arm720t_exec_command_handlers,
-	},
 	COMMAND_REGISTRATION_DONE
 };
 
@@ -560,6 +475,7 @@ struct target_type arm720t_target = {
 	.deassert_reset = arm7_9_deassert_reset,
 	.soft_reset_halt = arm720t_soft_reset_halt,
 
+	.get_gdb_arch = arm_get_gdb_arch,
 	.get_gdb_reg_list = arm_get_gdb_reg_list,
 
 	.read_memory = arm720t_read_memory,
@@ -582,6 +498,7 @@ struct target_type arm720t_target = {
 	.commands = arm720t_command_handlers,
 	.target_create = arm720t_target_create,
 	.init_target = arm720t_init_target,
+	.deinit_target = arm720t_deinit_target,
 	.examine = arm7_9_examine,
 	.check_reset = arm7_9_check_reset,
 };
