@@ -1,17 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2015 by Esben Haabendal                                 *
- *   eha@deif.com                                                          *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- ***************************************************************************/
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+/*
+ * Copyright (C) 2015 by Esben Haabendal <eha@deif.com>
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -64,14 +55,14 @@ static int ls1_sap_halt(struct target *target)
 	return ERROR_OK;
 }
 
-static int ls1_sap_resume(struct target *target, int current, uint32_t address,
+static int ls1_sap_resume(struct target *target, int current, target_addr_t address,
 		int handle_breakpoints, int debug_execution)
 {
 	LOG_DEBUG("%s", __func__);
 	return ERROR_OK;
 }
 
-static int ls1_sap_step(struct target *target, int current, uint32_t address,
+static int ls1_sap_step(struct target *target, int current, target_addr_t address,
 				int handle_breakpoints)
 {
 	LOG_DEBUG("%s", __func__);
@@ -113,7 +104,7 @@ static void ls1_sap_set_instr(struct jtag_tap *tap, uint32_t new_instr)
 static void ls1_sap_set_addr_high(struct jtag_tap *tap, uint16_t addr_high)
 {
 	struct scan_field field;
-	uint8_t buf[2];
+	uint8_t buf[2] = { 0 };
 
 	ls1_sap_set_instr(tap, 0x21);
 
@@ -130,7 +121,7 @@ static void ls1_sap_memory_cmd(struct jtag_tap *tap, uint32_t address,
 			       int32_t size, bool rnw)
 {
 	struct scan_field field;
-	uint8_t cmd[8];
+	uint8_t cmd[8] = { 0 };
 
 	ls1_sap_set_instr(tap, 0x24);
 
@@ -178,13 +169,13 @@ static void ls1_sap_memory_write(struct jtag_tap *tap, uint32_t size,
 	jtag_add_dr_scan(tap, 1, &field, TAP_IDLE);
 }
 
-static int ls1_sap_read_memory(struct target *target, uint32_t address,
+static int ls1_sap_read_memory(struct target *target, target_addr_t address,
 			       uint32_t size, uint32_t count, uint8_t *buffer)
 {
-	LOG_DEBUG("Reading memory at physical address 0x%" PRIx32
-		  "; size %" PRId32 "; count %" PRId32, address, size, count);
+	LOG_DEBUG("Reading memory at physical address 0x%" TARGET_PRIxADDR
+		  "; size %" PRIu32 "; count %" PRIu32, address, size, count);
 
-	if (count == 0 || buffer == NULL)
+	if (count == 0 || !buffer)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	ls1_sap_set_addr_high(target->tap, 0);
@@ -199,15 +190,15 @@ static int ls1_sap_read_memory(struct target *target, uint32_t address,
 	return jtag_execute_queue();
 }
 
-static int ls1_sap_write_memory(struct target *target, uint32_t address,
+static int ls1_sap_write_memory(struct target *target, target_addr_t address,
 				uint32_t size, uint32_t count,
 				const uint8_t *buffer)
 {
-	LOG_DEBUG("Writing memory at physical address 0x%" PRIx32
-		  "; size %" PRId32 "; count %" PRId32, address, size, count);
+	LOG_DEBUG("Writing memory at physical address 0x%" TARGET_PRIxADDR
+		  "; size %" PRIu32 "; count %" PRIu32, address, size, count);
 
 
-	if (count == 0 || buffer == NULL)
+	if (count == 0 || !buffer)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	ls1_sap_set_addr_high(target->tap, 0);
