@@ -1,21 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2013 Andes Technology                                   *
  *   Hsiangkai Wang <hkwang@andestech.com>                                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.           *
  ***************************************************************************/
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,7 +13,7 @@
 
 static bool nds32_reg_init_done;
 static struct nds32_reg_s nds32_regs[TOTAL_REG_NUM];
-static struct nds32_reg_exception_s nds32_ex_reg_values[] = {
+static const struct nds32_reg_exception_s nds32_ex_reg_values[] = {
 	{IR0, 3, 0x3, 2},
 	{IR0, 3, 0x3, 3},
 	{IR1, 3, 0x3, 2},
@@ -358,7 +345,7 @@ const char *nds32_reg_symbolic_name(uint32_t number)
 bool nds32_reg_exception(uint32_t number, uint32_t value)
 {
 	int i;
-	struct nds32_reg_exception_s *ex_reg_value;
+	const struct nds32_reg_exception_s *ex_reg_value;
 	uint32_t field_value;
 
 	i = 0;
@@ -369,7 +356,7 @@ bool nds32_reg_exception(uint32_t number, uint32_t value)
 			field_value = (value >> ex_reg_value->ex_value_bit_pos) &
 				ex_reg_value->ex_value_mask;
 			if (field_value == ex_reg_value->ex_value) {
-				LOG_WARNING("It will generate exceptions as setting %" PRId32 " to %s",
+				LOG_WARNING("It will generate exceptions as setting %" PRIu32 " to %s",
 						value, nds32_regs[number].simple_mnemonic);
 				return true;
 			}
