@@ -1,19 +1,9 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *                                                                         *
  * Copyright (C) ST-Ericsson SA 2011                                       *
  * Author: Michel Jaouen <michel.jaouen@stericsson.com> for ST-Ericsson.   *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -28,6 +18,7 @@
 #include "smp.h"
 #include "helper/binarybuffer.h"
 
+/* DEPRECATED: gdb_read_smp_packet/gdb_write_smp_packet to be removed      */
 /*  implementation of new packet in gdb interface for smp feature          */
 /*                                                                         */
 /*   j : smp  status request                                               */
@@ -53,11 +44,15 @@
 /*  maint packet jc                                                        */
 
 /* packet j :smp status request */
+#define DEPRECATED_MSG "DEPRECATED: This method is deprecated in favor of the hwthread pseudo RTOS"
 int gdb_read_smp_packet(struct connection *connection,
 		char const *packet, int packet_size)
 {
 	struct target *target = get_target_from_connection(connection);
 	int retval = ERROR_OK;
+
+	LOG_WARNING(DEPRECATED_MSG);
+
 	if (target->smp) {
 		if (strncmp(packet, "jc", 2) == 0) {
 			const uint32_t len = sizeof(target->gdb_service->core[0]);
@@ -83,6 +78,8 @@ int gdb_write_smp_packet(struct connection *connection,
 	int coreid = 0;
 	int retval = ERROR_OK;
 
+	LOG_WARNING(DEPRECATED_MSG);
+
 	/* skip command character */
 	if (target->smp) {
 		if (strncmp(packet, "Jc", 2) == 0) {
@@ -96,3 +93,74 @@ int gdb_write_smp_packet(struct connection *connection,
 
 	return retval;
 }
+
+COMMAND_HANDLER(default_handle_smp_command)
+{
+	struct target *target = get_current_target(CMD_CTX);
+	struct target_list *head;
+
+	if (CMD_ARGC > 1)
+		return ERROR_COMMAND_SYNTAX_ERROR;
+
+	if (!CMD_ARGC) {
+		command_print(CMD, "%s", target->smp ? "on" : "off");
+		return ERROR_OK;
+	}
+
+	if (!strcmp(CMD_ARGV[0], "on")) {
+		foreach_smp_target(head, target->smp_targets)
+			head->target->smp = 1;
+
+		return ERROR_OK;
+	}
+
+	if (!strcmp(CMD_ARGV[0], "off")) {
+		foreach_smp_target(head, target->smp_targets)
+			head->target->smp = 0;
+
+		/* fixes the target display to the debugger */
+		if (!list_empty(target->smp_targets))
+			target->gdb_service->target = target;
+
+		return ERROR_OK;
+	}
+
+	return ERROR_COMMAND_SYNTAX_ERROR;
+}
+
+COMMAND_HANDLER(handle_smp_gdb_command)
+{
+	struct target *target = get_current_target(CMD_CTX);
+	int retval = ERROR_OK;
+	if (!list_empty(target->smp_targets)) {
+		if (CMD_ARGC == 1) {
+			int coreid = 0;
+			COMMAND_PARSE_NUMBER(int, CMD_ARGV[0], coreid);
+			if (retval != ERROR_OK)
+				return retval;
+			target->gdb_service->core[1] = coreid;
+
+		}
+		command_print(CMD, "gdb coreid  %" PRId32 " -> %" PRId32, target->gdb_service->core[0]
+			, target->gdb_service->core[1]);
+	}
+	return ERROR_OK;
+}
+
+const struct command_registration smp_command_handlers[] = {
+	{
+		.name = "smp",
+		.handler = default_handle_smp_command,
+		.mode = COMMAND_EXEC,
+		.help = "smp handling",
+		.usage = "[on|off]",
+	},
+	{
+		.name = "smp_gdb",
+		.handler = handle_smp_gdb_command,
+		.mode = COMMAND_EXEC,
+		.help = "display/fix current core played to gdb",
+		.usage = "",
+	},
+	COMMAND_REGISTRATION_DONE
+};
