@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /***************************************************************************
  *   Copyright (C) 2007 by Dominic Rath                                    *
  *   Dominic.Rath@gmx.de                                                   *
@@ -7,19 +9,6 @@
  *                                                                         *
  *   Copyright (C) 2008 by Spencer Oliver                                  *
  *   spen@spen-soft.co.uk                                                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -56,7 +45,7 @@ static int target_asciimsg(struct target *target, uint32_t length)
 	LOG_DEBUG("%s", msg);
 
 	while (c) {
-		command_print(c->cmd_ctx, "%s", msg);
+		command_output_text(c->cmd_ctx, msg);
 		c = c->next;
 	}
 
@@ -100,7 +89,7 @@ static int target_hexmsg(struct target *target, int size, uint32_t length)
 			LOG_DEBUG("%s", line);
 
 			while (c) {
-				command_print(c->cmd_ctx, "%s", line);
+				command_output_text(c->cmd_ctx, line);
 				c = c->next;
 			}
 			c = target->dbgmsg;
@@ -158,7 +147,7 @@ static int add_debug_msg_receiver(struct command_context *cmd_ctx, struct target
 {
 	struct debug_msg_receiver **p = &target->dbgmsg;
 
-	if (target == NULL)
+	if (!target)
 		return ERROR_COMMAND_SYNTAX_ERROR;
 
 	/* see if there's already a list */
@@ -186,9 +175,9 @@ static struct debug_msg_receiver *find_debug_msg_receiver(struct command_context
 	int do_all_targets = 0;
 
 	/* if no target has been specified search all of them */
-	if (target == NULL) {
+	if (!target) {
 		/* if no targets haven been specified */
-		if (all_targets == NULL)
+		if (!all_targets)
 			return NULL;
 
 		target = all_targets;
@@ -217,9 +206,9 @@ int delete_debug_msg_receiver(struct command_context *cmd_ctx, struct target *ta
 	int do_all_targets = 0;
 
 	/* if no target has been specified search all of them */
-	if (target == NULL) {
+	if (!target) {
 		/* if no targets haven been specified */
-		if (all_targets == NULL)
+		if (!all_targets)
 			return ERROR_OK;
 
 		target = all_targets;
@@ -234,7 +223,7 @@ int delete_debug_msg_receiver(struct command_context *cmd_ctx, struct target *ta
 			if (c->cmd_ctx == cmd_ctx) {
 				*p = next;
 				free(c);
-				if (*p == NULL) {
+				if (!*p) {
 					/* disable callback */
 					target->dbg_msg_enabled = 0;
 				}
@@ -256,13 +245,13 @@ COMMAND_HANDLER(handle_target_request_debugmsgs_command)
 
 	int receiving = 0;
 
-	if (target->type->target_request_data == NULL) {
+	if (!target->type->target_request_data) {
 		LOG_ERROR("Target %s does not support target requests", target_name(target));
 		return ERROR_OK;
 	}
 
-	/* see if reciever is already registered */
-	if (find_debug_msg_receiver(CMD_CTX, target) != NULL)
+	/* see if receiver is already registered */
+	if (find_debug_msg_receiver(CMD_CTX, target))
 		receiving = 1;
 
 	if (CMD_ARGC > 0) {
@@ -283,7 +272,7 @@ COMMAND_HANDLER(handle_target_request_debugmsgs_command)
 			return ERROR_COMMAND_SYNTAX_ERROR;
 	}
 
-	command_print(CMD_CTX, "receiving debug messages from current target %s",
+	command_print(CMD, "receiving debug messages from current target %s",
 			(receiving) ? (charmsg_mode ? "charmsg" : "enabled") : "disabled");
 	return ERROR_OK;
 }
